@@ -98,6 +98,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Използване на аватари тип Gravatar и favicon",
     "Register as application for mail links" : "Регистрирайте се като приложение за пощенски връзки",
     "Register" : "Регистрация",
+    "Shared with me" : "Споделено с мен",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешаване на приложението да събира данни за вашите взаимодействия. Въз основа на тези данни приложението ще се адаптира към вашите предпочитания. Данните ще се съхраняват само локално.",
     "Trusted senders" : "Доверени податели",
     "Manage S/MIME certificates" : "Управление на S/MIME сертификати",
@@ -115,6 +116,7 @@ OC.L10N.register(
     "Search" : "Търси",
     "Send" : "Изпрати",
     "Refresh" : "Опресняване",
+    "Ok" : "Добре",
     "No certificate" : "Няма сертификат",
     "Certificate updated" : "Актуализиран е сертификат",
     "Could not update certificate" : "Сертификата не можа да се актуализира",
@@ -202,7 +204,6 @@ OC.L10N.register(
     "More actions" : "Повече действия",
     "Back" : "Назад",
     "Edit as new message" : "Редактиране като ново съобщение",
-    "Create event" : "Създаване на събитие",
     "Create task" : "Създаване на задача",
     "Download message" : "Изтегляне на съобщение",
     "Load more" : "Зареждане на още",
@@ -217,10 +218,14 @@ OC.L10N.register(
     "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["{number} не са спам","{number}не е спам "],
     "_Move {number} thread_::_Move {number} threads_" : ["Преместване на {number} нишки","Преместване на {number} нишки"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препращане {number} като прикачен файл","Препращане {number} като прикачен файл"],
+    "Mark as unread" : "Маркиране като непрочетено",
+    "Mark as read" : "Маркиране като прочетено",
     "Report this bug" : "Докладване на тази грешка",
     "Event created" : "Събитието е създадено",
     "Could not create event" : "Несупешно създаване на събитие",
+    "Create event" : "Създаване на събитие",
     "All day" : "Цял ден",
+    "Attendees" : "Участници",
     "Description" : "Описание",
     "Create" : "Създаване",
     "This event was updated" : "Това събитие беше актуализирано",
@@ -248,6 +253,10 @@ OC.L10N.register(
     "email" : "имейл",
     "Itinerary for {type} is not supported yet" : "Маршрутът за {type} все още не се поддържа",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Нямате право да преместите това съобщение в архивната папка и/или да изтриете това съобщение от текущата папка",
+    "Last hour" : "Последния  час",
+    "Today" : "Днес",
+    "Last week" : "Миналата седмица",
+    "Last month" : "Миналия месец",
     "Loading messages …" : "Зареждане на съобщения ...",
     "Choose target folder" : "Избор на папка",
     "No more submailboxes in here" : "Тук няма повече допълнителни пощенски кутии",
@@ -300,7 +309,7 @@ OC.L10N.register(
     "Move up" : "Преместване нагоре",
     "Move down" : "Преместване  надолу",
     "Show all folders" : "Покажи всички папки",
-    "Collapse mailboxes" : "Свиване на пощенските кутии",
+    "Collapse folders" : "Свиване на папки",
     "_{total} message_::_{total} messages_" : ["{total} съобщения","{total} съобщения"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочетени от {total}","{unread} непрочетени от {total}"],
     "Loading …" : "Зарежда …",
@@ -405,8 +414,6 @@ OC.L10N.register(
     "Reply to sender only" : "Отговор само на подателя",
     "Mark as unfavorite" : "Маркиране като непредпочитано",
     "Mark as favorite" : "Маркиране като любими",
-    "Mark as unread" : "Маркиране като непрочетено",
-    "Mark as read" : "Маркиране като прочетено",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Прекратяването на абонамента ще спре всички съобщения от пощенския списък {sender}",
     "Could not remove trusted sender {sender}" : "Не можа да бъде премахнат доверен подател {sender}",
     "No senders are trusted at the moment." : "В момента няма доверени податели.",
@@ -523,6 +530,9 @@ OC.L10N.register(
     "Private key (optional)" : "Частен ключ (по избор)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Частният ключ е необходим само ако възнамерявате да изпращате подписани и криптирани имейли, като използвате този сертификат.",
     "Submit" : "Изпращане",
+    "Shared" : "Споделен",
+    "Shares" : "Споделени",
+    "Insert" : "Вмъкване",
     "Account connected" : "Профилът е свързан",
     "You can close this window" : "Можете да затворите този прозорец",
     "Connect your mail account" : "Свързване към ваш имейл профил",
@@ -555,29 +565,6 @@ OC.L10N.register(
     "Redirect" : "Пренасочване",
     "The link leads to %s" : "Връзката води до %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желаете да посетите тази страница, може да се върнете към <a href=\"%s\">Поща</a>.",
-    "Continue to %s" : "Продължи към %s",
-    "Mailbox search" : "Търсене в пощата",
-    "No messages in this mailbox" : "Няма съобщения в тази пощенска кутия",
-    "No trash mailbox configured" : "Няма конфигурирана пощенска кутия за боклук",
-    "Draft: " : "Чернова: ",
-    "To archive a message please configure an archive mailbox in account settings" : "За архивиране на съобщение, конфигурирайте архивна пощенска кутия в настройките на вашият профил",
-    "Could not open mailbox" : "Пощенската кутия не можа да се отвори",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Индексиране на вашите съобщения. Това може да отнеме малко повече време за по-големи пощенски кутии.",
-    "Choose target mailbox" : "Избор на целева пощенска кутия ",
-    "Show only subscribed mailboxes" : "Показване само на абонирани пощенски кутии",
-    "Add mailbox" : "Добавяне на пощенски кутии",
-    "Show all subscribed mailboxes" : "Показване на всички абонирани пощенски кутии",
-    "Show all mailboxes" : "Показване на всички пощенски кутии",
-    "Clear mailbox" : "Изчистване на пощенска кутия",
-    "The mailbox and all messages in it will be deleted." : "Пощенската кутия и всички съобщения в нея ще бъдат изтрити.",
-    "Delete mailbox" : "Изтриване на пощенска кутия",
-    "Delete mailbox {name}" : "Изтриване на пощенска кутия {name}",
-    "Mark all messages of this mailbox as read" : "Маркирай всички съобщения в тази пощенска кутия като прочетени",
-    "Add submailbox" : "Добавяне на допълнителна пощенска кутия",
-    "Move mailbox" : "Преместване на пощенска кутия",
-    "No sent mailbox configured. Please pick one in the account settings." : "Конфигурирана е No sent /не изпраща поща, а само получава/ пощенска кутия. Моля, изберете една от настройките на профила.",
-    "Search in mailbox" : "Търсене в пощенската кутия",
-    "Actions" : "Действия",
-    "New action" : "Ново действие"
+    "Continue to %s" : "Продължи към %s"
 },
 "nplurals=2; plural=(n != 1);");
