@@ -19,21 +19,24 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "পাঠাও",
     "Refresh" : "নবোদ্যম",
+    "Ok" : "তথাস্তু",
     "Choose" : "বেছে নিন",
     "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
     "Favorite" : "প্রিয়জন",
     "Read" : "পড়",
     "Edit tags" : "ট্যাগ সম্পাদনা",
     "Back" : "পেছনে যাও",
+    "Attendees" : "অংশগ্রহণকারীবৃন্দ",
     "Description" : "বিবরণ",
     "Create" : "তৈরী কর",
     "Select" : "সিলেক্ট",
     "Comment" : "মন্তব্য",
     "Remove" : "অপসারণ",
+    "Today" : "আজ",
     "Other" : "অন্যান্য",
     "Choose a folder to store the attachment in" : "সংযুক্তি সংরক্ষনের জন্য একটি ফোল্ডার নির্বাচন করুন",
     "Move" : "Move",
-    "Quota" : "কোটা",
+    "Folder name" : "ফোলডারের নাম",
     "Mark all as read" : "সব পঠিত হিসেবে চিহ্নিত কর",
     "Rename" : "পূনঃনামকরণ",
     "Clear cache" : "ক্যাশে পরিষ্কার কর",
@@ -47,8 +50,10 @@ OC.L10N.register(
     "User" : "User",
     "Host" : "হোস্ট",
     "Port" : "পোর্ট",
+    "Group" : "গোষ্ঠীসমূহ",
+    "Shared" : "ভাগাভাগিকৃত",
+    "Shares" : "ভাগাভাগি",
     "All" : "সবাই",
-    "Favorites" : "প্রিয়জন",
-    "Actions" : "পদক্ষেপসমূহ"
+    "Favorites" : "প্রিয়জন"
 },
 "nplurals=2; plural=(n != 1);");
