@@ -134,6 +134,7 @@ OC.L10N.register(
     "Mailto" : "Mailto",
     "Register as application for mail links" : "Erregistratu posta-estekentzako aplikazio bezala",
     "Register" : "Erregistratu",
+    "Shared with me" : "Nirekin partekatuta",
     "Privacy and security" : "Pribatutasuna eta segurtasuna",
     "Data collection consent" : "Datuak biltzeko baimena",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Baimena eman aplikazioari zure interakzioei buruzko datuak biltzeko. Datu horietan oinarrituta, aplikazioa zure hobespenetara egokituko da. Datuak lokalki bakarrik gordeko dira.",
@@ -160,6 +161,7 @@ OC.L10N.register(
     "Search" : "Bilatu",
     "Send" : "Bidali",
     "Refresh" : "Freskatu",
+    "Ok" : "Ados",
     "No certificate" : "Ziurtagiririk ez",
     "Certificate updated" : "Ziurtagiria eguneratu da",
     "Could not update certificate" : "Ezin izan da ziurtagiria eguneratu",
@@ -267,7 +269,6 @@ OC.L10N.register(
     "Back" : "Atzera",
     "Set custom snooze" : "Ezarri atzerapen pertsonalizatua",
     "Edit as new message" : "Aldatu mezu berri gisa",
-    "Create event" : "Sortu gertaera",
     "Create task" : "Sortu zeregina",
     "Download message" : "Deskargatu mezua",
     "Load more" : "Kargatu gehiago",
@@ -283,10 +284,14 @@ OC.L10N.register(
     "_Edit tags for {number}_::_Edit tags for {number}_" : ["Editatu {number}-en etiketak","Editatu  {number}-ren etiketak"],
     "_Move {number} thread_::_Move {number} threads_" : ["Mugitu hari {number}","Mugitu {number} hari"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Birbidali {zenbakia} eranskin bezala","Birbidali {zenbakia} eranskin bezala"],
+    "Mark as unread" : "Markatu ez irakurritako gisa",
+    "Mark as read" : "Markatu irakurritako gisa",
     "Report this bug" : "Eman errore honen berri",
     "Event created" : "Sortu da gertaera",
     "Could not create event" : "Ezin izan da gertaera sortu",
+    "Create event" : "Sortu gertaera",
     "All day" : "Egun osoa",
+    "Attendees" : "Partaideak",
     "Select calendar" : "Hautatu egutegia",
     "Description" : "Deskripzioa",
     "Create" : "Sortu",
@@ -319,6 +324,10 @@ OC.L10N.register(
     "Add internal email or domain" : "Gehitu barneko helbide elektronikoa edo domeinua",
     "Itinerary for {type} is not supported yet" : "{type} motarentzako ibilbidea ez da onartzen oraindik",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Ez duzu mezu hau artxibo karpetara eramateko eta/edo mezu hau uneko karpetatik ezabatzeko baimenik",
+    "Last hour" : "Azken ordua",
+    "Today" : "Gaur",
+    "Last week" : "Joan den astean",
+    "Last month" : "Joan den hilabetean",
     "Loading messages …" : "Mezuak kargatzen ...",
     "Choose target folder" : "Aukeratu helburuko karpeta",
     "No more submailboxes in here" : "Azpipostontzi gehiagorik ez hemen",
@@ -533,8 +542,6 @@ OC.L10N.register(
     "Reply to sender only" : "Erantzun bakarrik igorleari",
     "Mark as unfavorite" : "Markatu ez gogoko gisa",
     "Mark as favorite" : "Markatu gogoko gisa",
-    "Mark as unread" : "Markatu ez irakurritako gisa",
-    "Mark as read" : "Markatu irakurritako gisa",
     "Unsubscribe via link" : "Harpidetza kendu esteka bidez",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Harpidetza kentzeak {sender} posta-zerrendako mezu guztiak geldituko ditu",
     "Send unsubscribe email" : "Bidali harpidetza kentzeko mezu elektronikoa",
@@ -703,6 +710,10 @@ OC.L10N.register(
     "Private key (optional)" : "Gako pribatua (aukerakoa)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Gako pribatua beharrezkoa da  soilik ziurtagiri hau erabiliz sinatutako eta enkriptatutako mezu elektronikoak bidaltzeko asmoa baduzu .",
     "Submit" : "Bidali",
+    "Group" : "Taldea",
+    "Shared" : "Partekatuta",
+    "Shares" : "Partekatzeak",
+    "Insert" : "Txertatu",
     "Account connected" : "Kontua konektatuta",
     "You can close this window" : "Leiho hau itxi dezakezu",
     "Connect your mail account" : "Konektatu zure posta kontua",
@@ -740,42 +751,6 @@ OC.L10N.register(
     "Redirect" : "Birbideratu",
     "The link leads to %s" : "Estekak hona bideratzen du: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Orrialde hori bisitatu nahi ez baduzu, itzul dezakezu <a href=\"%s\">Mail </a>-ra.",
-    "Continue to %s" : "Jarraitu hona: %s",
-    "Mailbox search" : "Postontziko bilaketa",
-    "Install Mailvelope browser extension by clicking here" : "Instalatu Mailvelope arakatzailearen luzapena hemen klik eginez",
-    "No messages in this mailbox" : "Mezurik ez postontzi honetan",
-    "No trash mailbox configured" : "Ez da zakarrontzirik konfiguratu",
-    "Draft: " : "Zirriborroa: ",
-    "To archive a message please configure an archive mailbox in account settings" : "Mezu bat artxibatzeko, konfiguratu artxiboko postontzi bat kontuaren ezarpenetan",
-    "Could not open mailbox" : "Ezin izan da postontzia ireki",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Zure mezuak indexatzen. Honek denbora dezente har dezake postontzi handietan.",
-    "Choose target mailbox" : "Aukeratu helburuko postontzia",
-    "Show only subscribed mailboxes" : "Erakutsi harpidetutako postontziak soilik",
-    "Add mailbox" : "Gehitu postontzia",
-    "Mailbox name" : "Postontziaren izena",
-    "Show all subscribed mailboxes" : "Erakutsi harpidetutako postontzi guztiak",
-    "Show all mailboxes" : "Erakutsi postontzi guztiak",
-    "Collapse mailboxes" : "Tolestu postontziak",
-    "Clear mailbox" : "Garbitu postontzia",
-    "The mailbox and all messages in it will be deleted." : "Postontzia eta bertan dauden mezu guztiak ezabatuko dira.",
-    "Delete mailbox" : "Ezabatu postontzia",
-    "Delete mailbox {name}" : "Ezabatu {name} postontzia",
-    "Mark all messages of this mailbox as read" : "Markatu postontzi honetako mezu guztiak irakurrita bezala",
-    "Add submailbox" : "Gehitu azpipostontzia",
-    "Move mailbox" : "Mugitu postontzia",
-    "Repair mailbox" : "Konpondu postontzia",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ez dago bidalitakoen postontzirik konfiguratuta. Aukeratu baten bat kontuaren ezarpenetan, mesedez.",
-    "Could not copy to \"Sent\" mailbox" : "Ezin izan da kopiatu \"Bidalitakoak\" postontzira",
-    "Copy to \"Sent\" Mailbox" : "Kopiatu \"Bidalitakoak\" postontzira",
-    "Copy to Sent Mailbox" : "Kopiatu Bidalitakoak postontzira",
-    "Search in mailbox" : "Bilatu postontzian",
-    "If all tests pass, then the actions will be executed" : "Proba guztiak gaindituz gero, ekintzak burutu egingo dira",
-    "If one test pass, then the actions will be executed" : "Proba bat gaindituz gero, ekintzak burutu egingo dira",
-    "Tests" : "Probak",
-    "New test" : "Proba berria",
-    "Actions" : "Ekintzak",
-    "New action" : "Ekintza berria",
-    "Message copied to \"Sent\" mailbox" : "Mezua \"Bidalitakoak\" postontzira kopiatu da",
-    "Could not copy message to \"Sent\" mailbox" : "Ezin izan da mezua \"Bidalitakoak\" postontzira kopiatu"
+    "Continue to %s" : "Jarraitu hona: %s"
 },
 "nplurals=2; plural=(n != 1);");
