@@ -75,6 +75,7 @@ OC.L10N.register(
     "Search" : "חיפוש",
     "Send" : "שליחה",
     "Refresh" : "רענון",
+    "Ok" : "אישור",
     "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
     "From" : "מאת",
     "Select account" : "בחר חשבון",
@@ -116,12 +117,15 @@ OC.L10N.register(
     "More actions" : "פעולות נוספות",
     "Back" : "חזרה",
     "Edit as new message" : "עריכה כהודעה חדשה",
-    "Create event" : "יצירת אירוע",
     "Load more" : "לטעון עוד",
     "_Mark {number} unread_::_Mark {number} unread_" : ["סימון {number} שלא נקראה","סימון {number} שלא נקראו","סימון {number} שלא נקראו"],
+    "Mark as unread" : "סימון כלא נקרא",
+    "Mark as read" : "סימון כנקרא",
     "Report this bug" : "דיווח על התקלה הזו",
     "Could not create event" : "לא ניתן ליצור אירוע",
+    "Create event" : "יצירת אירוע",
     "All day" : "כל היום",
+    "Attendees" : "משתתפים",
     "Description" : "תיאור",
     "Create" : "יצירה",
     "Select" : "בחירה",
@@ -133,6 +137,11 @@ OC.L10N.register(
     "Remove" : "הסרה",
     "email" : "דוא״ל",
     "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
+    "Last hour" : "השעה החולפת",
+    "Today" : "היום",
+    "Yesterday" : "מחר",
+    "Last week" : "שבוע שעבר",
+    "Last month" : "חודש שעבר",
     "Choose target folder" : "נא לבחור תיקיית יעד",
     "Important info" : "מידע חשוב",
     "Other" : "אחר",
@@ -200,8 +209,6 @@ OC.L10N.register(
     "Could not load your message thread" : "לא ניתן לטעון את שרשור ההודעות שלך",
     "Not found" : "לא נמצא",
     "Reply to sender only" : "להגיב לשולח בלבד",
-    "Mark as unread" : "סימון כלא נקרא",
-    "Mark as read" : "סימון כנקרא",
     "Could not remove trusted sender {sender}" : "לא ניתן להסיר את השולח המאומת {sender}",
     "No senders are trusted at the moment." : "אין שולחים מהימנים כרגע.",
     "Untitled event" : "אירוע ללא כותרת",
@@ -236,6 +243,10 @@ OC.L10N.register(
     "Valid until" : "בתוקף עד",
     "Certificate" : "אישור",
     "Submit" : "שליחה",
+    "Guest" : "אורח",
+    "Group" : "קבוצה",
+    "Shared" : "משותף",
+    "Shares" : "שיתופים",
     "Account connected" : "חשבון מחובר",
     "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
     "All" : "הכול",
@@ -263,20 +274,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "יש ללחוץ כאן אם לא הועברת אוטומטית בשניות הקרובות.",
     "Redirect" : "הפנייה",
     "The link leads to %s" : "הקישור מוביל אל %s",
-    "Continue to %s" : "ממשיך אל %s",
-    "No messages in this mailbox" : "אין הודעות בתיבת הדוא״ל הזאת",
-    "No trash mailbox configured" : "לא הוגדרה תיבת דוא״ל לאשפה",
-    "Draft: " : "טיוטה:",
-    "Could not open mailbox" : "לא ניתן לפתוח את תיבת הדואר",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
-    "Add mailbox" : "הוספת תיבת דוא״ל",
-    "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
-    "Collapse mailboxes" : "צמצום תיבות דוא״ל",
-    "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
-    "Delete mailbox" : "מחיקת תיבת דוא״ל",
-    "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
-    "Mark all messages of this mailbox as read" : "סימון כל ההודעות בתיבת הדוא״ל הזו כנקראו",
-    "Add submailbox" : "הוספת תת־תיבת דוא״ל",
-    "Actions" : "פעולות"
+    "Continue to %s" : "ממשיך אל %s"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
