@@ -68,6 +68,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Upotrijebi avatare Gravatar i Favicon",
     "Register as application for mail links" : "Registriraj kao aplikaciju za poveznice e-pošte",
     "Register" : "Registriraj se",
+    "Shared with me" : "Dijeljeno sa mnom",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
     "Trusted senders" : "Pouzdani pošiljatelji",
     "About" : "Informacije",
@@ -82,6 +83,7 @@ OC.L10N.register(
     "Search" : "Traži",
     "Send" : "Pošalji",
     "Refresh" : "Osvježi",
+    "Ok" : "U redu",
     "Message {id} could not be found" : "Poruka {id} nije pronađena",
     "From" : "Od",
     "Select account" : "Odaberi račun",
@@ -125,7 +127,6 @@ OC.L10N.register(
     "More actions" : "Dodatne radnje",
     "Back" : "Natrag",
     "Edit as new message" : "Uredi kao novu poruku",
-    "Create event" : "Stvori događaj",
     "Create task" : "Stvori zadatak",
     "Load more" : "Učitaj više",
     "_Mark {number} read_::_Mark {number} read_" : ["Označi {number} kao pročitano","Označi {number} kao pročitano","Označi {number} kao pročitano"],
@@ -137,10 +138,14 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Poništi odabir {number}","Poništi odabir {number}","Poništi odabir {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Premjesti {number} dretvu","Premjesti {number} dretve","Premjesti {number} dretvi"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Proslijedi {number} kao privitak","Proslijedi {number} kao privitak","Proslijedi {number} kao privitak"],
+    "Mark as unread" : "Označi kao nepročitano",
+    "Mark as read" : "Označi kao pročitano",
     "Report this bug" : "Prijavi ovu pogrešku",
     "Event created" : "Događaj je stvoren",
     "Could not create event" : "Nije moguće stvoriti događaj",
+    "Create event" : "Stvori događaj",
     "All day" : "Cijeli dan",
+    "Attendees" : "Sudionici",
     "Description" : "Opis",
     "Create" : "Stvori",
     "Select" : "Odaberi",
@@ -153,6 +158,9 @@ OC.L10N.register(
     "Remove" : "Ukloni",
     "email" : "e-pošta",
     "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
+    "Last hour" : "Posljednji sat",
+    "Last week" : "Prošli tjedan",
+    "Last month" : "Prošli mjesec",
     "Choose target folder" : "Odaberi ciljnu mapu",
     "No more submailboxes in here" : "Ovdje više nema podsandučića",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Poruke se automatski označavaju kao važne na temelju poruka kojima ste rukovali ili koje ste označili kao važne. U početku ćete možda morati ručno mijenjati važnost poruka kako bi sustav zapamtio vaše želje, ali s vremenom će se poboljšati.",
@@ -262,8 +270,6 @@ OC.L10N.register(
     "Not found" : "Nije pronađeno",
     "Unsubscribe" : "Otkaži pretplatu",
     "Reply to sender only" : "Odgovori pošiljatelju",
-    "Mark as unread" : "Označi kao nepročitano",
-    "Mark as read" : "Označi kao pročitano",
     "Could not remove trusted sender {sender}" : "Nije moguće ukloniti pouzdanog pošiljatelja {sender}",
     "No senders are trusted at the moment." : "Trenutno nema pouzdanih pošiljatelja.",
     "Untitled event" : "Događaj bez naslova",
@@ -346,6 +352,8 @@ OC.L10N.register(
     "Valid until" : "Vrijedi do",
     "Certificate" : "Vjerodajnica",
     "Submit" : "Šalji",
+    "Shared" : "Dijeljeno",
+    "Shares" : "Dijeljeni resursi",
     "Account connected" : "Račun povezan",
     "Connect your mail account" : "Poveži svoj račun e-pošte",
     "All" : "Sve",
@@ -373,24 +381,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Kliknite ovdje ako niste preusmjereni automatski unutar sljedećih nekoliko sekundi.",
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
-    "Continue to %s" : "Idi do %s",
-    "No messages in this mailbox" : "Nema poruka u ovom sandučiću",
-    "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
-    "Draft: " : "Skica: ",
-    "Could not open mailbox" : "Nije moguće otvoriti sandučić",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksiranje poruka u tijeku. Ova radnja može potrajati za veće sandučiće.",
-    "Choose target mailbox" : "Odaberi ciljni sandučić",
-    "Show only subscribed mailboxes" : "Prikaži samo pretplaćene sandučiće",
-    "Add mailbox" : "Dodaj sandučić",
-    "Show all subscribed mailboxes" : "Prikaži sve pretplaćene sandučiće",
-    "Show all mailboxes" : "Prikaži sve sandučiće",
-    "Collapse mailboxes" : "Sakrij sandučiće",
-    "The mailbox and all messages in it will be deleted." : "Izbrisat će se sandučić i sve pripadajuće poruke.",
-    "Delete mailbox" : "Izbriši sandučić",
-    "Delete mailbox {name}" : "Izbriši sandučić {name}",
-    "Mark all messages of this mailbox as read" : "Označi sve poruke u ovom sandučiću kao pročitane",
-    "Add submailbox" : "Dodaj podsandučić",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nije konfiguriran sandučić za poslanu poštu. Odaberite ga u postavkama računa.",
-    "Actions" : "Radnje"
+    "Continue to %s" : "Idi do %s"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
