@@ -108,6 +108,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Gravatar és favicon profilképek használata",
     "Register as application for mail links" : "Alkalmazás beállítása a levélhivatkozásokhoz",
     "Register" : "Regisztráció",
+    "Shared with me" : "Megosztva velem",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Engedélyezés az alkalmazásnak, hogy az adatokat gyűjtsön az interakcióiról. Az adatok alapján az alkalmazás alkalmazkodni fog a használati szokásaihoz. Az adatok helyben lesznek tárolva.",
     "Trusted senders" : "Megbízható küldők",
     "Manage S/MIME certificates" : "S/MIME tanúsítványok kezelése",
@@ -125,6 +126,7 @@ OC.L10N.register(
     "Search" : "Keresés",
     "Send" : "Küldés",
     "Refresh" : "Frissítés",
+    "Ok" : "Rendben",
     "No certificate" : "Nincs tanúsítvány",
     "Certificate updated" : "Tanúsítvány frissítve",
     "Could not update certificate" : "A tanúsítvány frissítése nem sikerült",
@@ -225,7 +227,6 @@ OC.L10N.register(
     "Back" : "Vissza",
     "Set custom snooze" : "Egyéni altatás beállítása",
     "Edit as new message" : "Szerkesztés új üzenetként",
-    "Create event" : "Esemény létrehozása",
     "Create task" : "Feladat létrehozása",
     "Download message" : "Üzenet letöltése",
     "Load more" : "Továbbiak betöltése",
@@ -241,10 +242,14 @@ OC.L10N.register(
     "_Edit tags for {number}_::_Edit tags for {number}_" : ["{number} címkéinek szerkesztése","{number} címkéinek szerkesztése"],
     "_Move {number} thread_::_Move {number} threads_" : ["{number} szál áthelyezése","{number} szál áthelyezése"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["{number} továbbítása mellékletként","{number} továbbítása mellékletként"],
+    "Mark as unread" : "Megjelölés olvasatlanként",
+    "Mark as read" : "Megjelölés olvasottként",
     "Report this bug" : "A hiba bejelentése",
     "Event created" : "Esemény létrehozása",
     "Could not create event" : "Nem sikerült létrehozni az eseményt",
+    "Create event" : "Esemény létrehozása",
     "All day" : "Egész nap",
+    "Attendees" : "Résztvevők",
     "Select calendar" : "Válasszon naptárat",
     "Description" : "Leírás",
     "Create" : "Létrehozás",
@@ -277,6 +282,10 @@ OC.L10N.register(
     "Add internal email or domain" : "Belső e-mail vagy tartomány hozzáadása",
     "Itinerary for {type} is not supported yet" : "A(z) {type} útiterve még nem támogatott",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nem helyezheti át ezt az üzenetet az archiválási mappába vagy törölheti a jelenlegi mappából",
+    "Last hour" : "Elmúlt óra",
+    "Today" : "Ma",
+    "Last week" : "Előző hét",
+    "Last month" : "Előző hónap",
     "Loading messages …" : "Üzenetek betöltése…",
     "Choose target folder" : "Válasszon célmappát",
     "No more submailboxes in here" : "Nem találhatók további alpostafiókok",
@@ -454,8 +463,6 @@ OC.L10N.register(
     "Reply to sender only" : "Válasz csak a feladónak",
     "Mark as unfavorite" : "Megjelölés nem kedvencként",
     "Mark as favorite" : "Megjelölés kedvencként",
-    "Mark as unread" : "Megjelölés olvasatlanként",
-    "Mark as read" : "Megjelölés olvasottként",
     "Unsubscribe via link" : "Leiratkozás hivatkozással",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "A leiratkozás leállít minden üzenetet, amely a(z) {sender} levelezőlistáról érkezik",
     "Send unsubscribe email" : "Leiratkozási e-mail küldése",
@@ -594,6 +601,10 @@ OC.L10N.register(
     "Private key (optional)" : "Titkos kulcs (nem kötelező)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "A titkos kulcs csak akkor szükséges, ha aláírt és titkosított e-maileket akar küldeni a tanúsítvány használatával.",
     "Submit" : "Beküldés",
+    "Group" : "Csoport",
+    "Shared" : "Megosztva",
+    "Shares" : "Megosztások",
+    "Insert" : "Beillesztés",
     "Account connected" : "Fiók csatlakoztatva",
     "You can close this window" : "Bezárhatja ezt az ablakot",
     "Connect your mail account" : "Kapcsolódás az e-mail-fiókjához",
@@ -631,30 +642,6 @@ OC.L10N.register(
     "Redirect" : "Átirányítás",
     "The link leads to %s" : "A hivatkozás ide mutat: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarja megnyitni azt az oldalt, akkor térjen vissza a <a href=\"%s\">Levelezéshez</a>.",
-    "Continue to %s" : "Folytatás ide: %s",
-    "No messages in this mailbox" : "Nincs üzenet ebben a postafiókban",
-    "No trash mailbox configured" : "Nincs mappa beállítva a törölt üzenetek számára",
-    "Draft: " : "Piszkozat: ",
-    "To archive a message please configure an archive mailbox in account settings" : "Egy üzenet archiválásához állítsa be az archiváláshoz használt postafiókot a fiókbeállításokban",
-    "Could not open mailbox" : "Nem sikerült megnyitni a postaládát",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Üzenetek indexelése folyamatban. Ez a folyamat tovább tarthat a nagyobb méretű postafiókok esetén.",
-    "Choose target mailbox" : "Válasszon cél postafiókot",
-    "Show only subscribed mailboxes" : "Csak a feliratkozott postafiókok megjelenítése",
-    "Add mailbox" : "Postaláda hozzáadása",
-    "Mailbox name" : "Postafiók név",
-    "Show all subscribed mailboxes" : "Összes feliratkozott postafiók megjelenítése",
-    "Show all mailboxes" : "Összes postafiók megjelenítése",
-    "Collapse mailboxes" : "Postaládák összecsukása",
-    "Clear mailbox" : "Postaláda ürítése",
-    "The mailbox and all messages in it will be deleted." : "A postafiók és az abban található összes üzenet törlődik.",
-    "Delete mailbox" : "Fiók törlése",
-    "Delete mailbox {name}" : "A(z) {name} postafiók törlése",
-    "Mark all messages of this mailbox as read" : "Postafiók összes üzenetének megjelölése olvasottként",
-    "Add submailbox" : "Alpostaláda hozzáadása",
-    "Move mailbox" : "Postaláda áthelyezése",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nincs beállítva mappa az elküldött üzenetek számára. Állítson be egyet a fiókbeállításokban.",
-    "Search in mailbox" : "Keresés a postaládában",
-    "Actions" : "Műveletek",
-    "New action" : "Új művelet"
+    "Continue to %s" : "Folytatás ide: %s"
 },
 "nplurals=2; plural=(n != 1);");
