@@ -96,6 +96,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Utilizza Gravatar e avatar favicon",
     "Register as application for mail links" : "Registra come applicazione per i collegamenti di posta",
     "Register" : "Registra",
+    "Shared with me" : "Condivisi con me",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Consenti all'applicazione di raccogliere dati sulle tue interazioni. Sulla base di questi dati, l'applicazione si adatterà alle tue preferenze. I dati saranno archiviati solo localmente.",
     "Trusted senders" : "Mittenti affidabili",
     "S/MIME" : "S/MIME",
@@ -113,6 +114,7 @@ OC.L10N.register(
     "Search" : "Cerca",
     "Send" : "Invia",
     "Refresh" : "Aggiorna",
+    "Ok" : "Ok",
     "No certificate" : "Nessun certificato",
     "Certificate updated" : "Certificato aggiornato",
     "Could not update certificate" : "Impossibile aggiornare il certificato",
@@ -199,7 +201,6 @@ OC.L10N.register(
     "More actions" : "Altre azioni",
     "Back" : "Indietro",
     "Edit as new message" : "Modifica come nuovo messaggio",
-    "Create event" : "Crea evento",
     "Create task" : "Crea attività",
     "Download message" : "Scarica messaggio",
     "Load more" : "Carica altro",
@@ -212,10 +213,14 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Deseleziona {number}","Deseleziona {number}","Deseleziona {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Sposta {number} conversazione","Sposta {number} conversazioni","Sposta {number} conversazioni"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Inoltra {number} come allegato","Inoltra {number} come allegati","Inoltra {number} come allegati"],
+    "Mark as unread" : "Segna come non letto",
+    "Mark as read" : "Segna come letto",
     "Report this bug" : "Segnala questo bug",
     "Event created" : "Evento creato",
     "Could not create event" : "Impossibile creare l'evento",
+    "Create event" : "Crea evento",
     "All day" : "Tutto il giorno",
+    "Attendees" : "Partecipanti",
     "Select calendar" : "Seleziona calendario",
     "Description" : "Descrizione",
     "Create" : "Crea",
@@ -243,6 +248,10 @@ OC.L10N.register(
     "Remove" : "Rimuovi",
     "Itinerary for {type} is not supported yet" : "L'itinerario per {type} non è ancora supportato",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Non ti è consentito spostare questo messaggio nella cartella degli archivi e/o eliminare questo messaggio dalla cartella corrente.",
+    "Last hour" : "Ultima ora",
+    "Today" : "Ogg",
+    "Last week" : "Ultima settimana",
+    "Last month" : "Ultimo mese",
     "Loading messages …" : "Caricamento messaggi...",
     "Choose target folder" : "Scegli la cartella di destinazione",
     "No more submailboxes in here" : "Qui non ci sono altre sotto-caselle di posta",
@@ -392,8 +401,6 @@ OC.L10N.register(
     "Reply all" : "Rispondi a tutti",
     "Unsubscribe" : "Rimuovi sottoscrizione",
     "Reply to sender only" : "Rispondi solo al mittente",
-    "Mark as unread" : "Segna come non letto",
-    "Mark as read" : "Segna come letto",
     "Go to latest message" : "Vai all'ultimo messaggio",
     "Go to newest message" : "Vai al messaggio più recente",
     "Translate from" : "Traduci da",
@@ -511,6 +518,10 @@ OC.L10N.register(
     "Private key (optional)" : "Chiave privata (facoltativa)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "La chiave privata è necessaria solo se si intende inviare email firmate e cifrate utilizzando questo certificato.",
     "Submit" : "Invia",
+    "Group" : "Gruppo",
+    "Shared" : "Condiviso",
+    "Shares" : "Condivisioni",
+    "Insert" : "Inserisci",
     "Account connected" : "Account connesso",
     "You can close this window" : "Puoi chiudere questa finestra",
     "Connect your mail account" : "Connetti il tuo account di posta",
@@ -546,26 +557,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Fai clic qui se non viene rediretto automaticamente entro pochi secondi.",
     "Redirect" : "Redirigi",
     "The link leads to %s" : "Il collegamento conduce a %s",
-    "Continue to %s" : "Continua su %s",
-    "No messages in this mailbox" : "Nessun messaggio in questa casella di posta",
-    "No trash mailbox configured" : "Nessuna casella del cestino configurata",
-    "Draft: " : "Bozza:",
-    "To archive a message please configure an archive mailbox in account settings" : "Per archiviare un messaggio, configura una casella di posta archivio nelle impostazioni dell'account.",
-    "Could not open mailbox" : "Impossibile aprire la casella di posta",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indicizzazione dei tuoi messaggi. Può richiedere più tempo per le caselle di posta più grandi.",
-    "Choose target mailbox" : "Scegli la casella di posta di destinazione",
-    "Show only subscribed mailboxes" : "Mostra solo le caselle di posta sottoscritte",
-    "Add mailbox" : "Aggiungi casella di posta",
-    "Show all subscribed mailboxes" : "Mostra tutte le caselle di posta sottoscritte",
-    "Show all mailboxes" : "Mostra tutte le caselle di posta",
-    "Collapse mailboxes" : "Contrai le caselle di posta",
-    "The mailbox and all messages in it will be deleted." : "La casella postale e tutti i messaggi in essa saranno eliminati.",
-    "Delete mailbox" : "Elimina casella di posta",
-    "Delete mailbox {name}" : "Elimina la casella di posta {name}",
-    "Mark all messages of this mailbox as read" : "Marca tutti i messaggi di questa casella di posta come letti",
-    "Add submailbox" : "Aggiungi sotto-casella di posta",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nessuna casella di posta inviata configurata. Scegline una nelle impostazioni dell'account.",
-    "Search in mailbox" : "Cerca nella casella di posta",
-    "Actions" : "Azioni"
+    "Continue to %s" : "Continua su %s"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
