@@ -161,6 +161,7 @@ OC.L10N.register(
     "Search" : "検索",
     "Send" : "送信",
     "Refresh" : "同期",
+    "Ok" : "OK",
     "No certificate" : "証明書がありません",
     "Certificate updated" : "証明書が更新されました",
     "Could not update certificate" : "証明書を更新できませんでした",
@@ -269,7 +270,6 @@ OC.L10N.register(
     "Back" : "戻る",
     "Set custom snooze" : "カスタムスヌーズを設定する",
     "Edit as new message" : "新しいメッセージとして編集",
-    "Create event" : "イベントを作成",
     "Create task" : "タスクを作成する",
     "Download message" : "メッセージをダウンロードする",
     "Load more" : "さらに読み込む",
@@ -285,10 +285,14 @@ OC.L10N.register(
     "_Edit tags for {number}_::_Edit tags for {number}_" : ["{number} のタグを編集"],
     "_Move {number} thread_::_Move {number} threads_" : ["{number}スレッドを移動する"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["{number} を添付ファイルとして転送"],
+    "Mark as unread" : "未読にする",
+    "Mark as read" : "既読にする",
     "Report this bug" : "不具合を報告",
     "Event created" : "イベントを作成しました",
     "Could not create event" : "イベントを作成できませんでした。",
+    "Create event" : "イベントを作成",
     "All day" : "終日",
+    "Attendees" : "参加者",
     "Select calendar" : "カレンダーを選択する",
     "Description" : "説明",
     "Create" : "作成",
@@ -321,6 +325,10 @@ OC.L10N.register(
     "Add internal email or domain" : "内部のメールアドレスまたはドメインを追加する",
     "Itinerary for {type} is not supported yet" : "{type} タイプの旅程はまだサポートされていません",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "このメッセージをアーカイブフォルダに移動したり、現在のフォルダから削除するは許可されていません",
+    "Last hour" : "1時間以内",
+    "Today" : "今日",
+    "Last week" : "先週",
+    "Last month" : "先月",
     "Loading messages …" : "メッセージの読み込み中…",
     "Choose target folder" : "ターゲットフォルダーを選択",
     "No more submailboxes in here" : "サブメールボックスはありません",
@@ -534,8 +542,6 @@ OC.L10N.register(
     "Reply to sender only" : "送信者のみに返信",
     "Mark as unfavorite" : "お気に入りから外す",
     "Mark as favorite" : "お気に入りにする",
-    "Mark as unread" : "未読にする",
-    "Mark as read" : "既読にする",
     "Unsubscribe via link" : "リンク経由で購読を解除する",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "リスト{sender}から全ての配信メッセージを停止する",
     "Send unsubscribe email" : "配信停止メールを送信する",
@@ -707,6 +713,10 @@ OC.L10N.register(
     "Private key (optional)" : "秘密鍵（オプション）",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "秘密鍵は、この証明書を使用して署名および暗号化された電子メールを送信する場合にのみ必要です。",
     "Submit" : "提出する",
+    "Group" : "グループ",
+    "Shared" : "共有中",
+    "Shares" : "共有",
+    "Insert" : "挿入する",
     "Account connected" : "アカウントに接続しました",
     "You can close this window" : "このウィンドウを閉じることができます",
     "Connect your mail account" : "あなたのメールアカウントに接続",
@@ -744,42 +754,6 @@ OC.L10N.register(
     "Redirect" : "リダイレクト",
     "The link leads to %s" : "リンクが %s につながります",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ページにアクセスしたくない場合は、<a href=\"%s\">メール</a>に戻ることができます",
-    "Continue to %s" : "%s にリダイレクトする",
-    "Mailbox search" : "メールボックスの検索",
-    "Install Mailvelope browser extension by clicking here" : "メールブラウザー拡張機能インストールしたい場合はここをクリックしてください",
-    "No messages in this mailbox" : "このメールボックスにメッセージはありません",
-    "No trash mailbox configured" : "ゴミ箱メールボックスが設定されていません",
-    "Draft: " : "下書き",
-    "To archive a message please configure an archive mailbox in account settings" : "メッセージをアーカイブするためにはアカウント設定からアーカイブメールボックスの設定をしてください",
-    "Could not open mailbox" : "メールボックスを開けませんでした",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "メールをインデックスしています。大きいメールボックスの場合はしばらくお待ちください。",
-    "Choose target mailbox" : "対象のメールボックスを選択してください",
-    "Show only subscribed mailboxes" : "購読したメールボックスのみ表示",
-    "Add mailbox" : "メールボックスを追加",
-    "Mailbox name" : "メールボックス名",
-    "Show all subscribed mailboxes" : "購読したメールボックスを全て表示",
-    "Show all mailboxes" : "全てのメールボックスを表示",
-    "Collapse mailboxes" : "メールボックスを非表示",
-    "Clear mailbox" : "メールボックスをクリアする",
-    "The mailbox and all messages in it will be deleted." : "メールボックスと中にある全てのメッセージが削除されます。",
-    "Delete mailbox" : "メールボックスを削除",
-    "Delete mailbox {name}" : "メールボックス「{name}」を削除",
-    "Mark all messages of this mailbox as read" : "このフォルダのすべてのメッセージを開封済みにする",
-    "Add submailbox" : "サブメールボックスを追加",
-    "Move mailbox" : "メールボックスを移動する",
-    "Repair mailbox" : "メールボックスを修復する",
-    "No sent mailbox configured. Please pick one in the account settings." : "送信済みのメールボックスはまだ設定されていません。アカウント設定から設定してください",
-    "Could not copy to \"Sent\" mailbox" : "\"送信済み\"メールボックスにコピーできませんでした",
-    "Copy to \"Sent\" Mailbox" : "「送信済み」メールボックスにコピー",
-    "Copy to Sent Mailbox" : "送信済みのメールボックスにコピーする",
-    "Search in mailbox" : "メールボックス内の検索",
-    "If all tests pass, then the actions will be executed" : "すべてのテストがパスすれば、アクションが実行されます",
-    "If one test pass, then the actions will be executed" : "テストが1つでもパスすれば、アクションが実行されます",
-    "Tests" : "テスト",
-    "New test" : "新しいテスト",
-    "Actions" : "アクション",
-    "New action" : "新しいアクション",
-    "Message copied to \"Sent\" mailbox" : "メッセージが\"送信済み\"メールボックスにコピーされました",
-    "Could not copy message to \"Sent\" mailbox" : "メッセージを”送信済み”メールボックスにコピーできませんでした"
+    "Continue to %s" : "%s にリダイレクトする"
 },
 "nplurals=1; plural=0;");
