@@ -45,6 +45,7 @@ OC.L10N.register(
     "Search" : "ძიება",
     "Send" : "გაგზავნა",
     "Refresh" : "განახლება",
+    "Ok" : "კარგი",
     "Select account" : "აირჩიეთ ანგარიში",
     "Subject" : "სათაური",
     "Upload attachment" : "დანართის ატვირთვა",
@@ -58,7 +59,10 @@ OC.L10N.register(
     "Edit tags" : "შეცვალეთ ტეგები",
     "More actions" : "მეტი ქმედება",
     "Back" : "უკან",
+    "Mark as unread" : "წაუკითხავად მონიშვნა",
+    "Mark as read" : "წაკითხულად მონიშვნა",
     "All day" : "მთელი დღე",
+    "Attendees" : "დამსწრეები",
     "Description" : "აღწერილობა",
     "Create" : "შექმნა",
     "Select" : "არჩევა",
@@ -67,6 +71,7 @@ OC.L10N.register(
     "Decline" : "ურაყოფა",
     "Remove" : "წაშლა",
     "email" : "ელ-ფოსტა",
+    "Today" : "დღეს",
     "Other" : "სხვა",
     "Forward" : "წინ",
     "Translate" : "გადათარგმნეთ",
@@ -100,8 +105,6 @@ OC.L10N.register(
     "Select tags" : "აირჩიეთ ტეგები",
     "Custom" : "ინდივიდუალური",
     "Add tag" : "ტეგის დამატება",
-    "Mark as unread" : "წაუკითხავად მონიშვნა",
-    "Mark as read" : "წაკითხულად მონიშვნა",
     "Recipient" : "მიმღები",
     "matches" : "ემთხვევა",
     "Priority" : "პრიორიტეტი",
@@ -114,6 +117,7 @@ OC.L10N.register(
     "Valid until" : "ვარგისია",
     "Certificate" : "სერტიფიკატი",
     "Submit" : "გაგზავნა",
+    "Shared" : "გაზიარებული",
     "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
     "All" : "ყველა",
     "Drafts" : "მონახაზები",
@@ -137,7 +141,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
     "Redirect" : "გადამისამართება",
     "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
-    "Continue to %s" : "%s-ისკენ გაგრძელება",
-    "Actions" : "მოქმედებები"
+    "Continue to %s" : "%s-ისკენ გაგრძელება"
 },
 "nplurals=2; plural=(n!=1);");
