@@ -20,16 +20,19 @@ OC.L10N.register(
     "Confirm" : "Serggeg",
     "Favorite" : "Menyif",
     "Back" : "Retour",
+    "Mark as unread" : "Creḍ ur yettwaɣra ara",
+    "Mark as read" : "Creḍ yettwaɣra",
     "Create" : "Snulfu-d",
     "Select" : "Fren",
     "Comment" : "Commentaire",
     "Remove" : "Kkes",
+    "Today" : "Ass-a",
     "Other" : "Wayeḍ",
     "Forward" : "Avancer",
     "Translate" : "Suqel",
     "Move" : "Senkez",
-    "Loading …" : "Asali ...",
     "Remove account" : "Kkes amiḍan",
+    "Loading …" : "Asali ...",
     "Rename" : "Beddel isem",
     "Reply" : "Err",
     "Retry" : "Ɛreḍ tikkelt-nniḍen",
@@ -38,6 +41,9 @@ OC.L10N.register(
     "Add" : "Rnu",
     "Close" : "Mdel",
     "Tags" : "Tibzimin",
+    "User" : "Aseqdac",
+    "Guest" : "Inebgi",
+    "Group" : "Agraw",
     "All" : "Akk",
     "Favorites" : "Imenyafen",
     "Inbox" : "Tanaka",
