@@ -16,13 +16,17 @@ OC.L10N.register(
     "Delete" : "លុប",
     "Search" : "Search",
     "Send" : "ផ្ញើ",
+    "Ok" : "ព្រម",
     "Choose" : "ជ្រើស",
     "Back" : "ត្រឡប់ក្រោយ",
+    "Attendees" : "អ្នក​ចូលរួម",
     "Description" : "ការ​អធិប្បាយ",
     "Create" : "បង្កើត",
     "Select" : "Select",
     "Comment" : "មតិ",
     "Remove" : "ដកចេញ",
+    "Today" : "ថ្ងៃ​នេះ",
+    "Yesterday" : "ម្សិលមិញ",
     "Other" : "ផ្សេងៗ",
     "Move" : "Move",
     "Folder name" : "ឈ្មោះ​ថត",
@@ -36,6 +40,8 @@ OC.L10N.register(
     "User" : "User",
     "Host" : "ម៉ាស៊ីន​ផ្ទុក",
     "Port" : "ច្រក",
+    "Shared" : "បាន​ចែក​រំលែក",
+    "Shares" : "ចែក​រំលែក",
     "All" : "ទាំងអស់",
     "Drafts" : "ពង្រាង",
     "Favorites" : "Favorites",
