@@ -155,6 +155,7 @@ OC.L10N.register(
     "Search" : "Søk",
     "Send" : "Send",
     "Refresh" : "Oppdater",
+    "Ok" : "Ok",
     "No certificate" : "Ingen sertifikat",
     "Certificate updated" : "Sertifikat oppdatert",
     "Could not update certificate" : "Kunne ikke oppdatere sertifikatet",
@@ -262,7 +263,6 @@ OC.L10N.register(
     "Back" : "Tilbake",
     "Set custom snooze" : "Angi tilpasset slumring",
     "Edit as new message" : "Rediger som ny melding",
-    "Create event" : "Opprettet hendelse",
     "Create task" : "Opprett oppgave",
     "Download message" : "Last ned melding",
     "Load more" : "Last mer",
@@ -278,10 +278,14 @@ OC.L10N.register(
     "_Edit tags for {number}_::_Edit tags for {number}_" : ["Rediger merkelapp for {number}","Rediger merkelapper for {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Flytt {number} tråd","Flytt {number} tråder"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Videresend {number} som vedlegg","Videresend {number} som vedlegg"],
+    "Mark as unread" : "Merk som ulest",
+    "Mark as read" : "Merk som lest",
     "Report this bug" : "Rapporter denne feilen",
     "Event created" : "Hendelse opprettet",
     "Could not create event" : "Kunne ikke opprette hendelsen",
+    "Create event" : "Opprettet hendelse",
     "All day" : "Hele dagen",
+    "Attendees" : "Deltakere",
     "Select calendar" : "Velg kalender",
     "Description" : "Beskrivelse",
     "Create" : "Opprett",
@@ -314,6 +318,11 @@ OC.L10N.register(
     "Add internal email or domain" : "Legg til intern e-post eller domene",
     "Itinerary for {type} is not supported yet" : "Reiserute for {type} støttes ikke ennå",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Du har ikke lov til å flytte denne meldingen til arkivmappen og/eller slette denne meldingen fra gjeldende mappe",
+    "Last hour" : "Siste time",
+    "Today" : "I dag",
+    "Yesterday" : "Igår",
+    "Last week" : "Forrige uke",
+    "Last month" : "Forrige måned",
     "Loading messages …" : "Laster meldinger ...",
     "Choose target folder" : "Velg målmappe",
     "No more submailboxes in here" : "Ingen flere underpostbokser her",
@@ -518,8 +527,6 @@ OC.L10N.register(
     "Reply to sender only" : "Svar kun til avsender",
     "Mark as unfavorite" : "Merk som ufavoritt",
     "Mark as favorite" : "Merk som favoritt",
-    "Mark as unread" : "Merk som ulest",
-    "Mark as read" : "Merk som lest",
     "Unsubscribe via link" : "Avslutt abonnement via kobling",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Hvis du avslutter abonnementet, stoppes alle meldinger fra adresselisten {avsender}",
     "Send unsubscribe email" : "Send e-post for avmelding",
@@ -666,6 +673,10 @@ OC.L10N.register(
     "Private key (optional)" : "Privat nøkkel (valgfritt)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Den private nøkkelen er bare nødvendig hvis du har tenkt å sende signerte og krypterte e-postmeldinger ved hjelp av dette sertifikatet.",
     "Submit" : "Send inn",
+    "Group" : "Gruppe",
+    "Shared" : "Delt",
+    "Shares" : "Delinger",
+    "Insert" : "Sett inn",
     "Account connected" : "Konto er koblet",
     "You can close this window" : "Du kan lukke dette vinduet",
     "Connect your mail account" : "Koble til din e-postkonto",
@@ -703,37 +714,6 @@ OC.L10N.register(
     "Redirect" : "Videresend",
     "The link leads to %s" : "Denne lenken leder til %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke vil besøke den siden, kan du gå tilbake til <a href=\"%s\">E-post</a>",
-    "Continue to %s" : "Fortsett til %s",
-    "Mailbox search" : "Søk i postboks",
-    "Install Mailvelope browser extension by clicking here" : "Installer Mailvelope-nettleserutvidelse ved å klikk her",
-    "No messages in this mailbox" : "Ingen meldinger i denne postboksen",
-    "No trash mailbox configured" : "Ingen søppelpostkasse konfigurert",
-    "Draft: " : "Kladd:",
-    "To archive a message please configure an archive mailbox in account settings" : "For å arkivere en melding, vennligst konfigurer en arkivpostkasse i kontoinnstillinger",
-    "Could not open mailbox" : "Kunne ikke åpne postboksen",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indekser meldingene dine. Dette kan ta litt lengre tid for større postbokser.",
-    "Choose target mailbox" : "Velg målpostboks",
-    "Show only subscribed mailboxes" : "Vis kun abonnerte postbokser",
-    "Add mailbox" : "Legg til postboks",
-    "Mailbox name" : "Postboksnavn",
-    "Show all subscribed mailboxes" : "Vis alle postbokser du abonnerer på",
-    "Show all mailboxes" : "Vis alle postbokser",
-    "Collapse mailboxes" : "Skjul postkasser",
-    "Clear mailbox" : "Tøm postboks",
-    "The mailbox and all messages in it will be deleted." : "Postboksen og alle meldinger i den vil bli slettet.",
-    "Delete mailbox" : "Slett postboks",
-    "Delete mailbox {name}" : "Slett postboks {name}",
-    "Mark all messages of this mailbox as read" : "Merk alle meldinger i denne postkassen som lest",
-    "Add submailbox" : "Legg til underpostboks",
-    "Move mailbox" : "Flytt postboks",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postboks konfigurert. Vennligs velg en i kontoinnstillingene.",
-    "Could not copy to \"Sent\" mailbox" : "Kunne ikke kopiere til \"Sendt\"-postboks",
-    "Copy to \"Sent\" Mailbox" : "Kopier til \"Sendt\"-postboks",
-    "Copy to Sent Mailbox" : "Kopier til Sendt-postboks",
-    "Search in mailbox" : "Søk i postboks",
-    "Actions" : "Handlinger",
-    "New action" : "Ny handling",
-    "Message copied to \"Sent\" mailbox" : "Melding kopiert til \"Sendt\"-postboks",
-    "Could not copy message to \"Sent\" mailbox" : "Kunne ikke kopiere melding til \"Sendt\"-postboks"
+    "Continue to %s" : "Fortsett til %s"
 },
 "nplurals=2; plural=(n != 1);");
