@@ -104,11 +104,12 @@ OC.L10N.register(
     "More actions" : "Mais ações",
     "Back" : "Anterior",
     "Edit as new message" : "Editar como nova mensagem",
-    "Create event" : "Criar evento",
     "Download message" : "Transferir mensagem",
     "Load more" : "Carregar mais",
     "Could not create event" : "Não foi possível criar o evento",
+    "Create event" : "Criar evento",
     "All day" : "Todo o dia",
+    "Attendees" : "Participantes",
     "Description" : "Descrição",
     "Create" : "Criar",
     "Select" : "Selecionar",
@@ -242,11 +243,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redirecionado dentro de segundos.",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "A ligação aponta para %s",
-    "Continue to %s" : "Continuar para %s",
-    "Draft: " : "Rascunho:",
-    "Add mailbox" : "Adicionar caixa de",
-    "Show all mailboxes" : "Mostrar todas as caixas de entrada",
-    "Actions" : "Ações",
-    "New action" : "Nova ação"
+    "Continue to %s" : "Continuar para %s"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
