@@ -94,8 +94,11 @@ OC.L10N.register(
     "Days after which messages in Trash will automatically be deleted:" : "Дни, после которых сообщения в Корзине будут автоматически удаляться:",
     "Autoresponder" : "Автоответчик",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматический ответ на входящие сообщения. Если кто-то отправит вам несколько сообщений, этот автоматический ответ будет отправляться не чаще одного раза в 4 дня.",
+    "Go to Sieve settings" : "Перейти в настройки Sieve",
     "Filters" : "Фильтры",
+    "Sieve script editor" : "Редактор Sieve",
     "Mail server" : "Почтовый сервер",
+    "Sieve server" : "Сервер Sieve",
     "Update alias" : "Обновить псевдоним",
     "Rename alias" : "Переименовать псевдоним",
     "Show update alias form" : "Показать обновления для формы alias",
@@ -122,15 +125,20 @@ OC.L10N.register(
     "List" : "Список",
     "Vertical split" : "Вертикальное разделение",
     "Horizontal split" : "Горизонтальное разделение",
+    "Message View Mode" : "Режим отображения сообщения",
     "Sorting" : "Сортировка",
     "Newest" : "Более новые",
     "Oldest" : "Более старые",
+    "Search in body" : "Искать в теле",
     "Reply text position" : "Позиция текста ответа",
     "Gravatar settings" : "Настройки Gravatar",
     "Use Gravatar and favicon avatars" : "Использовать значки Gravatar и favicon",
     "Mailto" : "Почтовый адрес",
     "Register as application for mail links" : "Зарегистрировать в качестве приложения для обработки почтовых ссылок",
     "Register" : "Регистрация",
+    "Text blocks" : "Текстовые блоки",
+    "Create a new text block" : "Создать новый текстовый блок",
+    "Shared with me" : "Поделились с вами",
     "Privacy and security" : "Конфиденциальность и безопасность",
     "Data collection consent" : "Согласие на сбор данных",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешить приложению собирать данные о взаимодействии.  Основываясь на этих данных, приложение адаптируется к вашим предпочтениям. Данные будут храниться только локально.",
@@ -157,6 +165,10 @@ OC.L10N.register(
     "Search" : "Поиск",
     "Send" : "Отправить",
     "Refresh" : "Обновить",
+    "New text block" : "Новый текстовый блок",
+    "Title of the text block" : "Заголовок текстового блока",
+    "Content of the text block" : "Содержимое текстового блока",
+    "Ok" : "OK",
     "No certificate" : "Нет сертификата",
     "Certificate updated" : "Сертификат обновлен",
     "Could not update certificate" : "Не удалось обновить сертификат",
@@ -179,6 +191,7 @@ OC.L10N.register(
     "From" : "От",
     "Select account" : "Выбрать аккаунт",
     "To" : "Кому",
+    "Cc/Bcc" : "Копия/СК",
     "Select recipient" : "Выберите получателя",
     "Contact or email address …" : "Имя или адрес электронной почты...",
     "Cc" : "Коп",
@@ -234,6 +247,7 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Установить напоминание на эти выходные",
     "Next week – {timeLocale}" : "Следующая неделя – {timeLocale}",
     "Set reminder for next week" : "Установить напоминание на следующую неделю",
+    "No trash folder configured" : "Папка корзины не настроена",
     "Could not delete message" : "Не удалось удалить сообщение",
     "Could not archive message" : "Не удалось заархивировать письмо",
     "Encrypted message" : "Зашифрованное сообщение",
@@ -247,6 +261,7 @@ OC.L10N.register(
     "Mark as spam" : "Пометить как спам",
     "Edit tags" : "Изменить метки",
     "Move thread" : "Переместить ветку",
+    "Move Message" : "Переместить сообщение",
     "Archive thread" : "Архивировать тему",
     "Archive message" : "Архивное сообщение",
     "Delete thread" : "Удалить ветку",
@@ -254,7 +269,6 @@ OC.L10N.register(
     "More actions" : "Больше действий",
     "Back" : "Назад",
     "Edit as new message" : "Редактировать как новое сообщение",
-    "Create event" : "Создать событие",
     "Create task" : "Создать задачу",
     "Download message" : "Скачать письмо",
     "Load more" : "Загрузить больше",
@@ -267,10 +281,14 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Отменить выбор {number} сообщения","Отменить выбор {number} сообщений","Отменить выбор {number} сообщений","Отменить выбор {number} сообщений"],
     "_Move {number} thread_::_Move {number} threads_" : ["Переместить {number} ветку","Переместить {number} ветки","Переместить {number} веток","Переместить {number} веток"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Переслать {number} сообщение как вложение","Переслать {number} сообщения как вложение","Переслать {number} сообщений как вложение","Переслать {number} сообщения как вложение"],
+    "Mark as unread" : "Пометить непрочитанным",
+    "Mark as read" : "Пометить прочитанным",
     "Report this bug" : "Отправить отчёт об этой ошибке",
     "Event created" : "Событие создано",
     "Could not create event" : "Не удалось создать событие",
+    "Create event" : "Создать событие",
     "All day" : "Весь день",
+    "Attendees" : "Участники",
     "Select calendar" : "Выбрать календарь",
     "Description" : "Описание",
     "Create" : "Создать",
@@ -303,6 +321,12 @@ OC.L10N.register(
     "Add internal email or domain" : "Добавить внутреннюю электронную почту или домен",
     "Itinerary for {type} is not supported yet" : "Маршруты типа {type} пока не поддерживаются",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Вам не разрешено перемещать это сообщение в архивную папку и/или удалять это сообщение из текущей папки.",
+    "Could not mark message as seen/unseen" : "Не удалось пометить сообщение как (не)прочтенное",
+    "Last hour" : "Последний час",
+    "Today" : "Сегодня",
+    "Last week" : "Последняя неделя",
+    "Last month" : "Последний месяц",
+    "Could not open folder" : "Не удалось открыть папку",
     "Loading messages …" : "Загрузка сообщений...",
     "Choose target folder" : "Выбор папки назначения",
     "No more submailboxes in here" : "Вложенные папки отсутствуют",
@@ -326,6 +350,7 @@ OC.L10N.register(
     "Forward message as attachment" : "Переслать сообщение вложением",
     "View source" : "Просмотреть исходный текст",
     "Print message" : "Распечатать сообщение",
+    "Create mail filter" : "Создать почтовый фильтр",
     "Download thread data for debugging" : "Скачать ветку для отладки",
     "Message body" : "Тело сообщения",
     "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Предупреждение: Подпись S/MIME этого сообщения не проверена. Отправитель может выдавать себя за кого-то другого!",
@@ -357,6 +382,8 @@ OC.L10N.register(
     "Moving" : "Выполняется перемещение",
     "Moving thread" : "Перемещение ветки",
     "Moving message" : "Сообщение перемещается",
+    "Used quota: {quota}% ({limit})" : "Использовано квоты: {quota}% ({limit})",
+    "Used quota: {quota}%" : "Использовано квоты: {quota}%",
     "Remove account" : "Удалить учётную запись",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Учётная запись {email} и сохранённые данные будут удалены из Nextcloud, но сохранятся на исходном почтовом сервере.",
     "Remove {email}" : "Удалить {email}",
@@ -369,11 +396,14 @@ OC.L10N.register(
     "Move up" : "Переместить выше",
     "Move down" : "Переместить ниже",
     "Show all subscribed folders" : "Показать все папки из подписки",
+    "Show all folders" : "Показать все папки",
+    "Collapse folders" : "Свернуть папки",
     "_{total} message_::_{total} messages_" : ["{total} письмо","{total} письма","{total} писем","{total} письма"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["Непрочитано {unread} из {total}","Непрочитано {unread} из {total}","Непрочитано {unread} из {total}","Непрочитано {unread} из {total}"],
     "Loading …" : "Загрузка ...",
     "All messages in mailbox will be deleted." : "Все сообщения в почтовом ящике будут удалены.",
     "Clear mailbox {name}" : "Очистить почтовый ящик {name}",
+    "Clear folder" : "Очистить папку",
     "The folder and all messages in it will be deleted." : "Папка и все находящиеся в ней письма будут удалены",
     "Delete folder" : "Удалить папку",
     "Delete folder {name}" : "Удалить папку «{name}»",
@@ -383,6 +413,7 @@ OC.L10N.register(
     "Add subfolder" : "Добавить подпапку",
     "Rename" : "Переименовать",
     "Move folder" : "Переместить папку",
+    "Repair folder" : "Исправить папку",
     "Clear cache" : "Очистить кэш",
     "Clear locally cached data, in case there are issues with synchronization." : "Очистить локальный кэш данных в случае проблем с синхронизацией.",
     "Subscribed" : "Подписано",
@@ -404,7 +435,7 @@ OC.L10N.register(
     "Error sending your message" : "Ошибка при отправке вашего сообщения",
     "Retry" : "Попробовать снова",
     "Warning sending your message" : "Предупреждать перед отправкой сообщения",
-    "Send anyway" : "Все равно отправить",
+    "Send anyway" : "Всё равно отправить",
     "Autoresponder off" : "Автоответчик выключен",
     "Autoresponder on" : "Автоответчик включен",
     "Autoresponder follows system settings" : "Автоответчик следует системным настройкам",
@@ -418,10 +449,12 @@ OC.L10N.register(
     "Save autoresponder" : "Сохранить автоответчик",
     "Could not open outbox" : "Не удалось открыть исходящие",
     "Pending or not sent messages will show up here" : "В этой папке будут представлены отложенные и неотправленные сообщения",
+    "Could not copy to \"Sent\" folder" : "Не удалось скопировать в папку \"Отправленные\"",
     "Mail server error" : "Ошибка почтового сервера",
     "Message could not be sent" : "Сообщение не может быть отправлено",
     "Message deleted" : "Сообщение удалено",
     "Phishing email" : "Фишинговое письмо",
+    "This email might be a phishing attempt" : "Это письмо может быть попыткой фишинга",
     "Hide suspicious links" : "Скрыть подозрительные ссылки",
     "Show suspicious links" : "Показать подозрительные ссылки",
     "link text" : "текст ссылки",
@@ -436,6 +469,8 @@ OC.L10N.register(
     "Show less" : "Показывать меньше",
     "Show more" : "Показывать больше",
     "Clear" : "Очистить",
+    "Search in folder" : "Искать в папке",
+    "Open search modal" : "Открыть окно поиска",
     "Close" : "Закрыть",
     "Search parameters" : "Параметры поиска",
     "Search subject" : "Тема поиска",
@@ -449,13 +484,20 @@ OC.L10N.register(
     "Select tags" : "Выбор меток",
     "Marked as" : "Отмечено как",
     "Has attachments" : "Имеет вложения",
+    "Mentions me" : "Упоминания меня",
     "Has attachment" : "Имеет вложение",
     "Last 7 days" : "Последние 7 дней",
     "From me" : "От меня",
+    "Enable sieve filter" : "Включить Sieve фильтр",
+    "Sieve host" : "Хост Sieve",
+    "Sieve security" : "Безопасность Sieve",
     "Sieve Port" : "Sieve порт",
+    "Sieve credentials" : "Учётные данные Sieve",
+    "IMAP credentials" : "Учётные данные IMAP",
     "Custom" : "Свои параметры",
     "Sieve User" : "Sieve пользователь",
     "Sieve Password" : "Sieve пароль",
+    "Oh snap!" : "Ой!",
     "Save sieve settings" : "Сохранить настройки sieve",
     "The syntax seems to be incorrect:" : "Синтаксис кажется неправильным:",
     "Save sieve script" : "Сохранить sieve скрипт",
@@ -483,6 +525,9 @@ OC.L10N.register(
     "Summarizing thread failed." : "Не удалось подвести итоги.",
     "Could not load your message thread" : "Ошибка загрузки ветки переписки",
     "The thread doesn't exist or has been deleted" : "Тема не существует или была удалена",
+    "Email was not able to be opened" : "Не удалось открыть email",
+    "Print" : "Печать",
+    "Could not print message" : "Не удалось напечатать сообщение",
     "Loading thread" : "Загрузка потока",
     "Not found" : "Не найдено",
     "Encrypted & verified " : "Зашифровано и проверено",
@@ -494,13 +539,12 @@ OC.L10N.register(
     "Reply all" : "Ответить всем",
     "Unsubscribe request sent" : "Запрос на отмену подписки отправлен",
     "Could not unsubscribe from mailing list" : "Не удалось отписаться от списка рассылки",
+    "Please wait for the message to load" : "Пожалуйста дождитесь загрузки сообщения",
     "Disable reminder" : "Отключить напоминание",
     "Unsubscribe" : "Отписаться",
     "Reply to sender only" : "Ответить только отправителю",
     "Mark as unfavorite" : "Отметить как неизбранное",
     "Mark as favorite" : "Отметить как избранное",
-    "Mark as unread" : "Пометить непрочитанным",
-    "Mark as read" : "Пометить прочитанным",
     "Unsubscribe via link" : "Отписаться по ссылке",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Отказ от подписки приведет к остановке всех сообщений из списка рассылки {sender}",
     "Send unsubscribe email" : "Отправить письмо об отказе от подписки",
@@ -509,6 +553,7 @@ OC.L10N.register(
     "Go to latest message" : "Перейти к последнему сообщению",
     "Go to newest message" : "Перейти к последнему сообщению",
     "Thread summary" : "Резюме темы",
+    "Please select languages to translate to and from" : "Выберите языки с которых и на которые переводить",
     "The message could not be translated" : "Сообщение не может быть переведено",
     "Translation copied to clipboard" : "Перевод скопирован в буфер обмена",
     "Translation could not be copied" : "Не удалось скопировать перевод",
@@ -532,16 +577,33 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} из {depStation} в {arrStation}",
     "Train from {depStation} to {arrStation}" : "Поезд из {depStation} в {arrStation}",
     "Train" : "Поезд",
+    "Delete action" : "Действие удаления",
     "Flag" : "Флаг",
+    "The stop action ends all processing" : "Остановка прекратит всё что выполняется",
+    "Sender" : "Отправитель",
     "Recipient" : "Получатель",
+    "Create a new mail filter" : "Создать новый почтовый фильтр",
     "Delete filter" : "Удалить фильтр",
+    "Are you sure to delete the mail filter?" : "Вы уверены, что хотите удалить почтовый фильтр?",
     "New filter" : "Новый фильтр",
+    "Filter saved" : "Фильтр сохранён",
+    "Could not save filter" : "Не удалось сохранить фильтр",
     "Filter deleted" : "Фильтр удалён",
+    "Could not delete filter" : "Не удалось удалить фильтр",
+    "Filter is active" : "Фильтр активен",
+    "Filter is not active" : "Фильтр не активен",
     "Operator" : "Оператор",
     "contains" : "содержит",
     "matches" : "соответствует",
+    "Update mail filter" : "Обновить почтовый фильтр",
     "Filter name" : "Имя фильтра",
+    "If all the conditions are met" : "Если все условия удовлетворены",
+    "If any of the conditions are met" : "Если любое из условий удовлетворено",
+    "Add condition" : "Добавить условие",
+    "Then perform these actions" : "Затем выполнить следующие действия",
+    "Add action" : "Добавить действие",
     "Priority" : "Приоритет",
+    "Enable filter" : "Включить фильтр",
     "Save filter" : "Сохранить фильтр",
     "Successfully updated config for \"{domain}\"" : "Конфигурация домена «{domain}» обновлена",
     "Error saving config" : "Не удалось сохранить параметры конфигурации",
@@ -582,6 +644,7 @@ OC.L10N.register(
     "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail позволяет пользователям получать доступ к своей электронной почте через IMAP. По соображениям безопасности этот доступ возможен только при подключении OAuth 2.0 или учетных записях Google, которые используют двухфакторную аутентификацию и пароли приложений.",
     "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Вам необходимо зарегистрировать новый идентификатор клиента для «веб-приложения» в консоли Google Cloud. Добавьте URL-адрес {url} в качестве URI авторизованного перенаправления.",
     "Microsoft integration" : "Интеграция с Microsoft",
+    "Redirect URI" : "Адрес перенаправления",
     "Successfully set up anti spam email addresses" : "Успешно установлены анти-спам адреса электронной почты",
     "Error saving anti spam email addresses" : "Ошибка при сохранении анти-спам адресов электронной почты",
     "Successfully deleted anti spam reporting email" : "Успешно удалён анти-спам адрес отчёта электронной почты",
@@ -618,7 +681,8 @@ OC.L10N.register(
     "Host" : "Имя или адрес сервера",
     "Port" : "Порт",
     "SMTP" : "SMTP",
-    "Use master password" : "Использовать главный пароль",
+    "Master password" : "Мастер пароль",
+    "Use master password" : "Использовать мастер пароль",
     "Sieve" : "Фильтры Sieve",
     "Enable sieve integration" : "Использовать поддержку Sieve",
     "LDAP aliases integration" : "Поддержка псевдонимов LDAP",
@@ -649,6 +713,24 @@ OC.L10N.register(
     "Private key (optional)" : "Закрытый ключ (необязательно)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Закрытый ключ необходим только в том случае, если вы собираетесь отправлять подписанные и зашифрованные электронные письма с использованием этого сертификата.",
     "Submit" : "Отправить ответ",
+    "No text blocks available" : "Нет доступных текстовых блоков",
+    "Text block deleted" : "Текстовый блок удалён",
+    "Failed to delete text block" : "Не удалось удалить текстовый блок",
+    "Text block shared with {sharee}" : "Текстовый блок в общем доступе с {sharee}",
+    "Failed to share text block with {sharee}" : "Не удалось поделиться текстовым блоком с {sharee}",
+    "Share deleted for {name}" : "Общее удалено для {name}",
+    "Failed to delete share with {name}" : "Не удалось удалить общее с {name}",
+    "Guest" : "Гость",
+    "Group" : "Группа",
+    "Failed to save text block" : "Не удалось сохранить текстовый блок",
+    "Shared" : "Опубликованное",
+    "Edit {title}" : "Редактировать {title}",
+    "Delete {title}" : "Удалить {title}",
+    "Edit text block" : "Редактировать текстовый блок",
+    "Shares" : "Приглашения",
+    "Search for users or groups" : "Поиск пользователей или групп",
+    "Insert" : "Вставить",
+    "Insert text block" : "Вставить блок текста",
     "Account connected" : "Аккаунт подключен",
     "You can close this window" : "Вы можете закрыть это окно",
     "Connect your mail account" : "Настройка учётной записи электронной почты",
@@ -667,12 +749,13 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n новое сообщение \nот {from}","%n новых сообщения \nот {from}","%n новых сообщений \nот {from}","%n новых сообщений \nот {from}"],
     "Nextcloud Mail" : "Почта Nextcloud",
-    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Сообщение уже находится в обработке. Если вы продолжите, все несохраненные изменения будут потеряны!",
+    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Сообщение уже находится в обработке. Если вы продолжите, все несохранённые изменения будут потеряны!",
     "Discard changes" : "Отменить изменения",
-    "Discard unsaved changes" : "Отменить несохраненные изменения",
+    "Discard unsaved changes" : "Отменить несохранённые изменения",
     "Keep editing message" : "Продолжайте редактировать сообщение",
     "Attachments were not copied. Please add them manually." : "Вложения не скопированы, добавьте их вручную.",
     "Could not create snooze mailbox" : "Не удалось создать почтовый ящик для отсрочки",
+    "Sending message…" : "Отправка сообщения…",
     "Message sent" : "Сообщение отправлено",
     "Could not send message" : "Не удалось отправить сообщение",
     "Could not load {tag}{name}{endtag}" : "Не удалось загрузить {tag}{name}{endtag}",
@@ -686,37 +769,6 @@ OC.L10N.register(
     "Redirect" : "Перенаправление",
     "The link leads to %s" : "Эта ссылка ведёт на %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Если вы не хотите посещать эту страницу, вы можете вернуться в <a href=\"%s\">Почту</a>",
-    "Continue to %s" : "Продолжать %s",
-    "Mailbox search" : "Поиск по почтовому ящику",
-    "Install Mailvelope browser extension by clicking here" : "Установите расширение браузера Mailvelope, нажав здесь",
-    "No messages in this mailbox" : "В этой папке нет сообщений",
-    "No trash mailbox configured" : "Папка «Удалённые» не настроена",
-    "Draft: " : "Черновик:",
-    "To archive a message please configure an archive mailbox in account settings" : "Чтобы заархивировать сообщение, настройте архивный почтовый ящик в настройках учетной записи.",
-    "Could not open mailbox" : "Невозможно открыть папку",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Выполняется индексация сообщений, это займёт некоторое время.",
-    "Choose target mailbox" : "Выберите папку",
-    "Show only subscribed mailboxes" : "Показать только папки из подписки",
-    "Add mailbox" : "Добавить папку",
-    "Mailbox name" : "Имя почтового ящика",
-    "Show all subscribed mailboxes" : "Показать все папки из подписки",
-    "Show all mailboxes" : "Показать все папки",
-    "Collapse mailboxes" : "Свернуть папки",
-    "Clear mailbox" : "Очистить почтовый ящик",
-    "The mailbox and all messages in it will be deleted." : "Папка и все письма в ней будут удалены.",
-    "Delete mailbox" : "Удалить папку",
-    "Delete mailbox {name}" : "Удалить папку {name}",
-    "Mark all messages of this mailbox as read" : "Пометить все сообщения в папке как прочитанные",
-    "Add submailbox" : "Добавить вложенную папку",
-    "Move mailbox" : "Переместить почтовый ящик",
-    "No sent mailbox configured. Please pick one in the account settings." : "Не настроена папка исходящих сообщений. Выберите ее в параметрах учётной записи.",
-    "Could not copy to \"Sent\" mailbox" : "Не удалось скопировать в почтовый ящик «Отправленные»",
-    "Copy to \"Sent\" Mailbox" : "Копировать в почтовый ящик «Отправленные»",
-    "Copy to Sent Mailbox" : "Копировать в почтовый ящик «Отправленные»",
-    "Search in mailbox" : "Искать в почтовом ящике",
-    "Actions" : "Действия",
-    "New action" : "Создать действие",
-    "Message copied to \"Sent\" mailbox" : "Сообщение скопировано в почтовый ящик «Отправленные»",
-    "Could not copy message to \"Sent\" mailbox" : "Не удалось скопировать сообщение в почтовый ящик «Отправленные»"
+    "Continue to %s" : "Продолжать %s"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
