@@ -64,6 +64,7 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Imprea Gravatar e avatar favicon",
     "Register as application for mail links" : "Registra comente aplicatzione pro is ligòngios de posta",
     "Register" : "Registra",
+    "Shared with me" : "Cumpartzidos cun megus",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permite a s'aplicatzione de regòllere datos subra is interatziones tuas. In sa base de custos datos, s'aplicatziones s'at a adatare a is preferèntzias tuas. Is datos ant a èssere archiviados in manera locale isceti. ",
     "Trusted senders" : "Imbiantes afidàbiles",
     "About" : "In contu de",
@@ -78,6 +79,7 @@ OC.L10N.register(
     "Search" : "Chirca",
     "Send" : "Imbia",
     "Refresh" : "Agiorna",
+    "Ok" : "AB",
     "Message {id} could not be found" : "Su messàgiu {id} no s'est pòdidu agatare",
     "From" : "Dae",
     "Select account" : "Seletziona contu",
@@ -125,7 +127,6 @@ OC.L10N.register(
     "More actions" : "Àteras atziones",
     "Back" : "In segus",
     "Edit as new message" : "Modìfica comente messàgiu nou",
-    "Create event" : "Crea eventu",
     "Create task" : "Crea faina",
     "Load more" : "Càrriga àteru",
     "_Mark {number} read_::_Mark {number} read_" : ["Marca {number} lèghidos","Marca {number} lèghidos"],
@@ -135,9 +136,13 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Deseletziona {number}","Deseletziona {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Tràmuda {number} dibatas","Tràmuda {number} dibatas"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Inoltra {number} comente alligongiados","Inoltra {number} comente alligongiadu"],
+    "Mark as unread" : "Marca comente non lèghidu",
+    "Mark as read" : "Marca comente lèghidu",
     "Report this bug" : "Signala cust'errore",
     "Could not create event" : "No at fatu a creare s'eventu",
+    "Create event" : "Crea eventu",
     "All day" : "Totu sa die",
+    "Attendees" : "Partetzipantes",
     "Description" : "Descritzione",
     "Create" : "Crea",
     "Select" : "Seletziona",
@@ -151,6 +156,10 @@ OC.L10N.register(
     "email" : "posta eletrònica",
     "Add internal address" : "Agiunghe indiritzu internu",
     "Itinerary for {type} is not supported yet" : "S'itineràriu pro {type} no est ancora suportadu",
+    "Last hour" : "Ùrtima ora",
+    "Today" : "Oe ",
+    "Yesterday" : "Cras",
+    "Last week" : "Sa chida passada",
     "Choose target folder" : "Sèbera cartella de destinatzione",
     "No more submailboxes in here" : "Non b'at àteras suta-cartellas inoghe",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Is messàgios s'ant a marcare in manera automàtica comente importantes in sa base de is messàgios cun is chi as tènnidu interatziones o chi si sunt marcados comente importantes. Fortzis a su cumintzu as a dèpere cambiare a manu s'importàntzia pro ddu imparare a su sistema, ma at a megiorare in su tempus.",
@@ -248,8 +257,6 @@ OC.L10N.register(
     "Not found" : "No agatadu",
     "Unsubscribe" : "Disiscrie·ti",
     "Reply to sender only" : "Responde isceti a chi at imbiadu",
-    "Mark as unread" : "Marca comente non lèghidu",
-    "Mark as read" : "Marca comente lèghidu",
     "Go to newest message" : "Bae a su messàgiu prus nou",
     "Could not remove trusted sender {sender}" : "No at fatu a nche bogare s'imbiante afidàbile {sender}",
     "No senders are trusted at the moment." : "No b'at imbiantes afidàbiles in custu momentu.",
@@ -315,6 +322,10 @@ OC.L10N.register(
     "E-mail address" : "Indiritzu de posta eletrònica",
     "Certificate" : "Tzertificadu",
     "Submit" : "Imbia",
+    "Guest" : "Persone invitada",
+    "Group" : "Grupu",
+    "Shared" : "Cumpartziduras",
+    "Shares" : "Cumpartziduras",
     "Account connected" : "Contu collegadu",
     "Connect your mail account" : "Connete·ti a su contu de posta tuo",
     "All" : "Totu",
@@ -342,26 +353,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Incarca inoghe chi no ses torradu a deretare in manera automàtica intro de pagu segundos.",
     "Redirect" : "Torra a deretare",
     "The link leads to %s" : "Su ligòngiu deretat a %s",
-    "Continue to %s" : "Sighi in %s",
-    "No messages in this mailbox" : "Perunu messàgiu in custa casella de posta",
-    "No trash mailbox configured" : "Peruna casella de àliga cunfigurada",
-    "Draft: " : "Brutacòpia:",
-    "Could not open mailbox" : "No at fatu a abèrrere sa casella de posta",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Inditzizende is messàgios. S'at a pòdere istentare unu pagu de prus cun casellas de posta prus mannas.",
-    "Choose target mailbox" : "Sèbera casella de posta de destinatzione",
-    "Show only subscribed mailboxes" : "Mustra isceti casellas de posta sutascritas",
-    "Add mailbox" : "Agiunghe casella de posta",
-    "Show all subscribed mailboxes" : "Mustra totu is casellas de posta sutascritas",
-    "Show all mailboxes" : "Mustra totu is casellas de posta",
-    "Collapse mailboxes" : "Istringhe is casellas de posta",
-    "The mailbox and all messages in it will be deleted." : "Sa casella de posta e is messàgios chi cuntenet ant a èssere cantzellados.",
-    "Delete mailbox" : "Cantzella casella de posta",
-    "Delete mailbox {name}" : "Cantzella casella de posta {name}",
-    "Mark all messages of this mailbox as read" : "Marca totu is messàgios de custa casella de posta comente lèghidos",
-    "Add submailbox" : "Agiunghe una sutacasella de posta",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nissuna casella de posta imbiada cunfigurada. Sèbera·nde una in sa cunfiguratzione de su contu.",
-    "New test" : "Proa noa",
-    "Actions" : "Atziones",
-    "New action" : "Atzione noa"
+    "Continue to %s" : "Sighi in %s"
 },
 "nplurals=2; plural=(n != 1);");
