@@ -161,7 +161,6 @@ OC.L10N.register(
     "More actions" : "Fler händelser",
     "Back" : "Tillbaka",
     "Edit as new message" : "Redigera som nytt meddelande",
-    "Create event" : "Skapa evenemang",
     "Create task" : "Skapa uppgift",
     "Load more" : "Ladda mer",
     "_Mark {number} read_::_Mark {number} read_" : ["Markera {number} meddelande som läst","Markera {number} meddelanden som lästa"],
@@ -171,10 +170,14 @@ OC.L10N.register(
     "_Unselect {number}_::_Unselect {number}_" : ["Avmarkera {number}","Avmarkera {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Flytta {number} tråd","Flytta {number} trådar"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Vidarebefordra {number} som bilaga","Vidarebefordra {number} som bilagor"],
+    "Mark as unread" : "Markera som oläst",
+    "Mark as read" : "Markera som läst",
     "Report this bug" : "Rapportera detta fel",
     "Event created" : "Evenemang skapat",
     "Could not create event" : "Kunde inte skapa händelse",
+    "Create event" : "Skapa evenemang",
     "All day" : "Hela dagen",
+    "Attendees" : "Deltagare",
     "Description" : "Beskrivning",
     "Create" : "Skapa",
     "Select" : "Välj",
@@ -299,8 +302,6 @@ OC.L10N.register(
     "Reply all" : "Svara alla",
     "Unsubscribe" : "Avsluta prenumeration",
     "Reply to sender only" : "Svara endast avsändaren",
-    "Mark as unread" : "Markera som oläst",
-    "Mark as read" : "Markera som läst",
     "The message could not be translated" : "Meddelandet kunde inte översättas",
     "Translation copied to clipboard" : "Översättningen har kopierats till urklipp",
     "Translation could not be copied" : "Översättningen kunde inte kopieras",
@@ -384,22 +385,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
     "Redirect" : "Omdirigera",
     "The link leads to %s" : "Länken pekar mot %s",
-    "Continue to %s" : "Fortsätt till %s",
-    "No messages in this mailbox" : "Inga meddelanden i den här brevlådan",
-    "No trash mailbox configured" : "Ingen skräpkorg är konfigurerad",
-    "Draft: " : "Utkast:",
-    "Could not open mailbox" : "Kunde inte öppna brevlådan",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexera dina meddelanden. Det kan ta lite längre tid för större brevlådor.",
-    "Choose target mailbox" : "Välj markerad inkorg",
-    "Show only subscribed mailboxes" : "Visa endast prenumererade brevlådor",
-    "Add mailbox" : "Lägg till brevlåda",
-    "Show all subscribed mailboxes" : "Visa alla prenumererade brevlådor",
-    "Show all mailboxes" : "Visa alla brevlådor",
-    "Collapse mailboxes" : "Minimera brevlådor",
-    "Delete mailbox" : "Radera brevlåda",
-    "Mark all messages of this mailbox as read" : "Markera alla meddelanden i den här brevlådan som lästa",
-    "Search in mailbox" : "Sök i brevlådan",
-    "Actions" : "Funktioner",
-    "New action" : "Ny åtgärd"
+    "Continue to %s" : "Fortsätt till %s"
 },
 "nplurals=2; plural=(n != 1);");
