@@ -134,6 +134,7 @@ OC.L10N.register(
     "Mailto" : "Mailto",
     "Register as application for mail links" : "خەت ئۇلانمىسىغا ئىلتىماس قىلىڭ",
     "Register" : "تىزىملىتىڭ",
+    "Shared with me" : "مەن بىلەن ئورتاقلاشتى",
     "Privacy and security" : "مەخپىيەتلىك ۋە بىخەتەرلىك",
     "Data collection consent" : "ئۇچۇر توپلاش ئىجازەتنامىسى",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "بۇ دېتالنىڭ ئۆز-ئارا تەسىرلىشىڭىزگە مۇناسىۋەتلىك ئۇچۇرلارنى توپلىشىغا يول قويۇڭ. بۇ سانلىق مەلۇماتلارغا ئاساسەن ، ئەپ سىزنىڭ مايىللىقىڭىزغا ماسلىشىدۇ. بۇ سانلىق مەلۇماتلار پەقەت يەرلىكتە ساقلىنىدۇ.",
@@ -159,6 +160,7 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "يوللا",
     "Refresh" : "يېڭىلا",
+    "Ok" : "جەزملە",
     "No certificate" : "گۇۋاھنامە يوق",
     "Certificate updated" : "گۇۋاھنامە يېڭىلاندى",
     "Could not update certificate" : "گۇۋاھنامىنى يېڭىلىيالمىدى",
@@ -263,14 +265,17 @@ OC.L10N.register(
     "Back" : "قايتىش",
     "Set custom snooze" : "ئىختىيارى ئۇخلاشنى تەڭشەڭ",
     "Edit as new message" : "يېڭى ئۇچۇر سۈپىتىدە تەھرىرلەڭ",
-    "Create event" : "ھادىسە قۇرۇش",
     "Create task" : "ۋەزىپە قۇرۇش",
     "Download message" : "ئۇچۇرنى چۈشۈرۈش",
     "Load more" : "تېخىمۇ كۆپ يۈكلەڭ",
+    "Mark as unread" : "ئوقۇلمىغان دەپ بەلگە قويۇڭ",
+    "Mark as read" : "ئوقۇغاندەك بەلگە قويۇڭ",
     "Report this bug" : "بۇ خاتالىقنى دوكلات قىلىڭ",
     "Event created" : "پائالىيەت قۇرۇلدى",
     "Could not create event" : "ھادىسە قۇرالمىدى",
+    "Create event" : "ھادىسە قۇرۇش",
     "All day" : "پۈتۈن كۈن",
+    "Attendees" : "قاتناشقۇچىلار",
     "Select calendar" : "كالېندارنى تاللاڭ",
     "Description" : "چۈشەندۈرۈش",
     "Create" : "قۇر",
@@ -303,6 +308,11 @@ OC.L10N.register(
     "Add internal email or domain" : "ئىچكى ئېلېكترونلۇق خەت ياكى دائىرە قوشۇڭ",
     "Itinerary for {type} is not supported yet" : "{type} نىڭ لىنىيىسى تېخىچە قوللىمايدۇ",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "بۇ ئۇچۇرنى ئارخىپ قىسقۇچقا يۆتكەش ۋە / ياكى بۇ ھۆججەتنى نۆۋەتتىكى ھۆججەت قىسقۇچتىن ئۆچۈرۈشكە بولمايدۇ",
+    "Last hour" : "ئالدىنقى سائەت",
+    "Today" : "بۈگۈن",
+    "Yesterday" : "تۈنۈگۈن",
+    "Last week" : "ئالدىنقى ھەپتە",
+    "Last month" : "ئالدىنقى ئاي",
     "Loading messages …" : "ئۇچۇرلارنى يۈكلەۋاتىدۇ…",
     "Choose target folder" : "نىشان ھۆججەت قىسقۇچىنى تاللاڭ",
     "No more submailboxes in here" : "بۇ يەردە باشقا خەت ساندۇقى يوق",
@@ -366,7 +376,6 @@ OC.L10N.register(
     "Saving" : "تېجەش",
     "Move up" : "يۆتكەڭ",
     "Move down" : "تۆۋەنگە يۆتكەڭ",
-    "Collapse mailboxes" : "خەت ساندۇقىنى يىمىرىڭ",
     "Loading …" : "Loading…",
     "All messages in mailbox will be deleted." : "خەت ساندۇقىدىكى بارلىق ئۇچۇرلار ئۆچۈرۈلىدۇ.",
     "Clear mailbox {name}" : "خەت ساندۇقىنى تازىلاش {name}",
@@ -507,8 +516,6 @@ OC.L10N.register(
     "Reply to sender only" : "ئەۋەتكۈچىگە جاۋاب قايتۇرۇڭ",
     "Mark as unfavorite" : "ياقتۇرمايدىغان دەپ بەلگە قويۇڭ",
     "Mark as favorite" : "ياقتۇرىدىغان دەپ بەلگە قويۇڭ",
-    "Mark as unread" : "ئوقۇلمىغان دەپ بەلگە قويۇڭ",
-    "Mark as read" : "ئوقۇغاندەك بەلگە قويۇڭ",
     "Unsubscribe via link" : "ئۇلىنىش ئارقىلىق مۇشتەرى بولۇڭ",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "مۇشتەرى بولۇش خەت ئەۋەتىش تىزىملىكىدىكى بارلىق ئۇچۇرلارنى توختىتىدۇ {sender}",
     "Send unsubscribe email" : "مۇشتەرى بولمىغان ئېلېكترونلۇق خەت ئەۋەتىڭ",
@@ -677,6 +684,11 @@ OC.L10N.register(
     "Private key (optional)" : "شەخسىي ئاچقۇچ (ئىختىيارى)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "ئەگەر بۇ گۇۋاھنامە ئارقىلىق ئىمزا قويۇلغان ۋە مەخپىيلەشتۈرۈلگەن ئېلېكترونلۇق خەت ئەۋەتمەكچى بولسىڭىز ، شەخسىي ئاچقۇچ تەلەپ قىلىنىدۇ.",
     "Submit" : "يوللاڭ",
+    "Guest" : "مېھمان",
+    "Group" : "گۇرۇپپا",
+    "Shared" : "ئورتاقلاشتى",
+    "Shares" : "Shares",
+    "Insert" : "قىستۇر",
     "Account connected" : "ھېسابات ئۇلاندى",
     "You can close this window" : "بۇ كۆزنەكنى ياپالايسىز",
     "Connect your mail account" : "خەت ساندۇقىڭىزنى ئۇلاڭ",
@@ -713,41 +725,6 @@ OC.L10N.register(
     "Redirect" : "قايتا نىشانلاش",
     "The link leads to %s" : "ئۇلىنىش% s نى كەلتۈرۈپ چىقىرىدۇ",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ئەگەر ئۇ بەتنى زىيارەت قىلىشنى خالىمىسىڭىز ، <a href = \"% s\"> خەت </a> گە قايتسىڭىز بولىدۇ.",
-    "Continue to %s" : "داۋاملىق% s",
-    "Mailbox search" : "خەت ساندۇقى ئىزدەش",
-    "Install Mailvelope browser extension by clicking here" : "بۇ يەرنى چېكىپ Mailvelope توركۆرگۈ كېڭەيتىلمىسىنى قاچىلاڭ",
-    "No messages in this mailbox" : "بۇ خەت ساندۇقىدا ھېچقانداق ئۇچۇر يوق",
-    "No trash mailbox configured" : "ئەخلەت خەت ساندۇقى سەپلەنمىگەن",
-    "Draft: " : "لايىھە: ",
-    "To archive a message please configure an archive mailbox in account settings" : "ئۇچۇرنى ئارخىپلاشتۇرۇش ئۈچۈن ھېسابات تەڭشىكىدە ئارخىپ خەت ساندۇقىنى سەپلەڭ",
-    "Could not open mailbox" : "خەت ساندۇقىنى ئاچالمىدى",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ئۇچۇرلىرىڭىزنى كۆرسەتمەكتە. چوڭراق خەت ساندۇقىغا بىر ئاز ئۇزۇن ۋاقىت كېتىدۇ.",
-    "Choose target mailbox" : "نىشان خەت ساندۇقىنى تاللاڭ",
-    "Show only subscribed mailboxes" : "پەقەت مۇشتەرى بولغان خەت ساندۇقىنىلا كۆرسىتىڭ",
-    "Add mailbox" : "خەت ساندۇقى قوشۇڭ",
-    "Mailbox name" : "خەت ساندۇقىنىڭ ئىسمى",
-    "Show all subscribed mailboxes" : "بارلىق مۇشتەرى بولغان خەت ساندۇقىنى كۆرسەت",
-    "Show all mailboxes" : "بارلىق خەت ساندۇقىنى كۆرسەت",
-    "Clear mailbox" : "خەت ساندۇقىنى تازىلاش",
-    "The mailbox and all messages in it will be deleted." : "خەت ساندۇقى ۋە ئۇنىڭدىكى بارلىق ئۇچۇرلار ئۆچۈرۈلىدۇ.",
-    "Delete mailbox" : "خەت ساندۇقىنى ئۆچۈرۈڭ",
-    "Delete mailbox {name}" : "خەت ساندۇقىنى ئۆچۈرۈڭ {name}",
-    "Mark all messages of this mailbox as read" : "بۇ خەت ساندۇقىنىڭ بارلىق ئۇچۇرلىرىنى ئوقۇغاندەك بەلگە قويۇڭ",
-    "Add submailbox" : "تارماق خەت ساندۇقى قوشۇڭ",
-    "Move mailbox" : "خەت ساندۇقىنى يۆتكەڭ",
-    "Repair mailbox" : "خەت ساندۇقىنى رېمونت قىلىڭ",
-    "No sent mailbox configured. Please pick one in the account settings." : "ئەۋەتىلگەن خەت ساندۇقى سەپلەنمىگەن. ھېسابات تەڭشىكىدىن بىرنى تاللاڭ.",
-    "Could not copy to \"Sent\" mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرەلمىدى",
-    "Copy to \"Sent\" Mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرۈڭ",
-    "Copy to Sent Mailbox" : "ئەۋەتىلگەن خەت ساندۇقىغا كۆچۈرۈڭ",
-    "Search in mailbox" : "خەت ساندۇقىدىن ئىزدەڭ",
-    "If all tests pass, then the actions will be executed" : "ئەگەر بارلىق سىناقلار ئۆتۈپ كەتسە ، ھەرىكەتلەر ئىجرا بولىدۇ",
-    "If one test pass, then the actions will be executed" : "ئەگەر بىر سىناقتىن ئۆتسە ، ئۇنداقتا ھەرىكەت ئىجرا بولىدۇ",
-    "Tests" : "سىناق",
-    "New test" : "يېڭى سىناق",
-    "Actions" : "مەشغۇلاتلار",
-    "New action" : "يېڭى ھەرىكەت",
-    "Message copied to \"Sent\" mailbox" : "ئۇچۇر «ئەۋەتىلگەن» خەت ساندۇقىغا كۆچۈرۈلدى",
-    "Could not copy message to \"Sent\" mailbox" : "«ئەۋەتىلگەن» خەت ساندۇقىغا ئۇچۇر كۆچۈرەلمىدى"
+    "Continue to %s" : "داۋاملىق% s"
 },
 "nplurals=2; plural=(n != 1);");
