@@ -69,6 +69,7 @@ OC.L10N.register(
     "Search" : "Tìm",
     "Send" : "Gởi",
     "Refresh" : "Làm mới",
+    "Ok" : "Đồng ý",
     "Message {id} could not be found" : "Không tìm thấy tin nhắn {id}",
     "From" : "Từ",
     "Select account" : "Chọn tài khoản",
@@ -107,7 +108,6 @@ OC.L10N.register(
     "More actions" : "Nhiều hành động hơn",
     "Back" : "Quay lại",
     "Edit as new message" : "Chỉnh sửa dưới dạng tin nhắn mới",
-    "Create event" : "Tạo sự kiện mới",
     "Load more" : "Tải thêm",
     "_Mark {number} read_::_Mark {number} read_" : ["Đánh dấu {number} đã đọc"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Đánh dấu {number} là chưa đọc"],
@@ -115,9 +115,13 @@ OC.L10N.register(
     "_Favorite {number}_::_Favorite {number}_" : ["Yêu thích {number}"],
     "_Unselect {number}_::_Unselect {number}_" : ["Bỏ chọn {number}"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Chuyển tiếp {number} dưới dạng tệp đính kèm"],
+    "Mark as unread" : "Đánh dấu là chưa đọc",
+    "Mark as read" : "Đánh dấu đã đọc",
     "Report this bug" : "Báo cáo lỗi này",
     "Could not create event" : "Không thể tạo sự kiện",
+    "Create event" : "Tạo sự kiện mới",
     "All day" : "Cả ngày",
+    "Attendees" : "Người tham gia",
     "Description" : "Mô tả",
     "Create" : "‎Tạo‎",
     "Select" : "Select",
@@ -129,6 +133,10 @@ OC.L10N.register(
     "Remove" : "Xóa",
     "email" : "Thư điện tử",
     "Itinerary for {type} is not supported yet" : "Hành trình cho {type} chưa được hỗ trợ",
+    "Today" : "Hôm nay",
+    "Yesterday" : "Hôm qua",
+    "Last week" : "Tuần trước",
+    "Last month" : "Tháng trước",
     "Choose target folder" : "Chọn thư mục đích",
     "No more submailboxes in here" : "Không còn hộp thư con nào ở đây",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Tin nhắn sẽ tự động được đánh dấu là quan trọng dựa trên những tin nhắn bạn đã tương tác hoặc được đánh dấu là quan trọng. Lúc đầu, bạn có thể phải thay đổi thủ công tầm quan trọng để dạy hệ thống, nhưng nó sẽ cải thiện theo thời gian.",
@@ -210,8 +218,6 @@ OC.L10N.register(
     "Could not load your message thread" : "Không thể tải chuỗi tin nhắn của bạn",
     "Not found" : "Không tìm thấy",
     "Reply to sender only" : "Chỉ trả lời người gửi",
-    "Mark as unread" : "Đánh dấu là chưa đọc",
-    "Mark as read" : "Đánh dấu đã đọc",
     "Could not remove trusted sender {sender}" : "Không thể xóa người gửi đáng tin cậy {sender}",
     "No senders are trusted at the moment." : "Không có người gửi nào được tin cậy vào lúc này.",
     "Untitled event" : "Sự kiện không tiêu đề",
@@ -246,6 +252,9 @@ OC.L10N.register(
     "Valid until" : "Có hiệu lực đến",
     "Certificate" : "Chứng chỉ",
     "Submit" : "Gửi",
+    "Group" : "Nhóm",
+    "Shared" : "Đã chia sẻ",
+    "Shares" : "Chia sẻ",
     "Account connected" : "Tài khoản đã được kết nối",
     "Connect your mail account" : "Kết nối tài khoản thư của bạn",
     "All" : "Tất cả",
@@ -272,24 +281,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Nhấp vào đây nếu bạn không được chuyển hướng tự động trong vòng vài giây tới",
     "Redirect" : "Chuyển hướng",
     "The link leads to %s" : "Liên kết dẫn đến %s",
-    "Continue to %s" : "Tiếp tục %s",
-    "No messages in this mailbox" : "Không có thư nào trong hộp thư này",
-    "No trash mailbox configured" : "Không có hộp thư thùng rác nào được định cấu hình",
-    "Draft: " : "Bản nháp: ",
-    "Could not open mailbox" : "Không thể mở hộp thư",
-    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Lập chỉ mục tin nhắn của bạn. Quá trình này có thể lâu hơn một chút đối với các hộp thư lớn.",
-    "Choose target mailbox" : "Chọn hộp thư mục tiêu",
-    "Show only subscribed mailboxes" : "Chỉ hiển thị các hộp thư đã đăng ký",
-    "Add mailbox" : "Thêm hộp thư",
-    "Show all subscribed mailboxes" : "Hiển thị tất cả các hộp thư đã đăng ký",
-    "Show all mailboxes" : "Hiển thị tất cả các hộp thư",
-    "Collapse mailboxes" : "Thu gọn hộp thư",
-    "The mailbox and all messages in it will be deleted." : "Hộp thư và tất cả thư trong đó sẽ bị xóa.",
-    "Delete mailbox" : "Xóa hộp thư",
-    "Delete mailbox {name}" : "Xóa hộp thư {name}",
-    "Mark all messages of this mailbox as read" : "Đánh dấu tất cả các thư của hộp thư này là đã đọc",
-    "Add submailbox" : "Thêm hộp thư con",
-    "No sent mailbox configured. Please pick one in the account settings." : "Không có hộp thư đã gửi nào được định cấu hình. Vui lòng chọn một trong cài đặt tài khoản.",
-    "Actions" : "Hành động"
+    "Continue to %s" : "Tiếp tục %s"
 },
 "nplurals=1; plural=0;");
