@@ -20,15 +20,14 @@ use OCA\Mail\IMAP\IMAPClientFactory;
 use OCA\Mail\Model\EventData;
 use OCA\Mail\Model\IMAPMessage;
 use OCP\IConfig;
+use OCP\IL10N;
 use OCP\TaskProcessing\IManager as TaskProcessingManager;
 use OCP\TaskProcessing\Task as TaskProcessingTask;
 use OCP\TaskProcessing\TaskTypes\TextToText;
 use OCP\TextProcessing\FreePromptTaskType;
-use OCP\TextProcessing\IManager;
+use OCP\TextProcessing\IManager as TextProcessingManager;
 use OCP\TextProcessing\SummaryTaskType;
-use OCP\TextProcessing\Task;
-use Psr\Container\ContainerExceptionInterface;
-use Psr\Container\ContainerInterface;
+use OCP\TextProcessing\Task as TextProcessingTask;
 use Psr\Log\LoggerInterface;
 
 use function array_map;
@@ -46,13 +45,14 @@ The email contents are:
 PROMPT;
 
 	public function __construct(
-		private ContainerInterface $container,
 		private LoggerInterface $logger,
 		private IConfig $config,
 		private Cache $cache,
 		private IMAPClientFactory $clientFactory,
 		private IMailManager $mailManager,
 		private TaskProcessingManager $taskProcessingManager,
+		private TextProcessingManager $textProcessingManager,
+		private IL10N $l,
 	) {
 	}
 
@@ -129,12 +129,7 @@ PROMPT;
 	 * @throws ServiceException
 	 */
 	public function summarizeThread(Account $account, string $threadId, array $messages, string $currentUserId): ?string {
-		try {
-			$manager = $this->container->get(IManager::class);
-		} catch (\Throwable $e) {
-			throw new ServiceException('Text processing is not available in your current Nextcloud version', 0, $e);
-		}
-		if (in_array(SummaryTaskType::class, $manager->getAvailableTaskTypes(), true)) {
+		if (in_array(SummaryTaskType::class, $this->textProcessingManager->getAvailableTaskTypes(), true)) {
 			$messageIds = array_map(function ($message) {
 				return $message->getMessageId();
 			}, $messages);
@@ -160,8 +155,8 @@ PROMPT;
 			}
 
 			$taskPrompt = implode("\n", $messagesBodies);
-			$summaryTask = new Task(SummaryTaskType::class, $taskPrompt, 'mail', $currentUserId, $threadId);
-			$manager->runTask($summaryTask);
+			$summaryTask = new TextProcessingTask(SummaryTaskType::class, $taskPrompt, 'mail', $currentUserId, $threadId);
+			$this->textProcessingManager->runTask($summaryTask);
 			$summary = $summaryTask->getOutput();
 
 			$this->cache->addValue($this->cache->buildUrlKey($messageIds), $summary);
@@ -176,13 +171,7 @@ PROMPT;
 	 * @param Message[] $messages
 	 */
 	public function generateEventData(Account $account, string $threadId, array $messages, string $currentUserId): ?EventData {
-		try {
-			/** @var IManager $manager */
-			$manager = $this->container->get(IManager::class);
-		} catch (ContainerExceptionInterface $e) {
-			return null;
-		}
-		if (!in_array(FreePromptTaskType::class, $manager->getAvailableTaskTypes(), true)) {
+		if (!in_array(FreePromptTaskType::class, $this->textProcessingManager->getAvailableTaskTypes(), true)) {
 			return null;
 		}
 		$client = $this->clientFactory->getClient($account);
@@ -201,14 +190,14 @@ PROMPT;
 			$client->logout();
 		}
 
-		$task = new Task(
+		$task = new TextProcessingTask(
 			FreePromptTaskType::class,
 			self::EVENT_DATA_PROMPT_PREAMBLE . implode("\n\n---\n\n", $messageBodies),
 			'mail',
 			$currentUserId,
 			"event_data_$threadId",
 		);
-		$result = $manager->runTask($task);
+		$result = $this->textProcessingManager->runTask($task);
 		try {
 			$decoded = json_decode($result, true, 512, JSON_THROW_ON_ERROR);
 			return new EventData($decoded['title'], $decoded['agenda']);
@@ -222,12 +211,7 @@ PROMPT;
 	 * @throws ServiceException
 	 */
 	public function getSmartReply(Account $account, Mailbox $mailbox, Message $message, string $currentUserId): ?array {
-		try {
-			$manager = $this->container->get(IManager::class);
-		} catch (\Throwable $e) {
-			throw new ServiceException('Text processing is not available in your current Nextcloud version', 0, $e);
-		}
-		if (in_array(FreePromptTaskType::class, $manager->getAvailableTaskTypes(), true)) {
+		if (in_array(FreePromptTaskType::class, $this->textProcessingManager->getAvailableTaskTypes(), true)) {
 			$cachedReplies = $this->cache->getValue('smartReplies_' . $message->getId());
 			if ($cachedReplies) {
 				return json_decode($cachedReplies, true, 512);
@@ -262,8 +246,8 @@ PROMPT;
 
 			Please, output *ONLY* a valid JSON string with the keys 'reply1' and 'reply2' for the reply suggestions. Leave out any other text besides the JSON! Be extremely succinct and write the replies from my point of view.
 			 ";
-			$task = new Task(FreePromptTaskType::class, $prompt, 'mail,', $currentUserId);
-			$manager->runTask($task);
+			$task = new TextProcessingTask(FreePromptTaskType::class, $prompt, 'mail,', $currentUserId);
+			$this->textProcessingManager->runTask($task);
 			$replies = $task->getOutput();
 			try {
 				$cleaned = preg_replace('/^```json\s*|\s*```$/', '', trim($replies));
@@ -289,17 +273,7 @@ PROMPT;
 		Message $message,
 		string $currentUserId,
 	): bool {
-		try {
-			$manager = $this->container->get(IManager::class);
-		} catch (ContainerExceptionInterface $e) {
-			throw new ServiceException(
-				'Text processing is not available in your current Nextcloud version',
-				0,
-				$e,
-			);
-		}
-
-		if (!in_array(FreePromptTaskType::class, $manager->getAvailableTaskTypes(), true)) {
+		if (!in_array(FreePromptTaskType::class, $this->textProcessingManager->getAvailableTaskTypes(), true)) {
 			throw new ServiceException('No language model available for smart replies');
 		}
 
@@ -338,21 +312,93 @@ Tell me what the function outputs for the following parameters.
 emailText: \"$messageBody\"
 The JSON output should be in the form: {\"expectsReply\": true}
 Never return null or undefined.";
-		$task = new Task(FreePromptTaskType::class, $prompt, Application::APP_ID, $currentUserId);
+		$task = new TextProcessingTask(FreePromptTaskType::class, $prompt, Application::APP_ID, $currentUserId);
 
-		$manager->runTask($task);
+		$this->textProcessingManager->runTask($task);
 
 		// Can't use json_decode() here because the output contains additional garbage
 		return preg_match('/{\s*"expectsReply"\s*:\s*true\s*}/i', $task->getOutput()) === 1;
 	}
 
-	public function isLlmAvailable(string $taskType): bool {
+	/**
+	 * Analyze whether an email is written in a specific language.
+	 *
+	 * @throws ServiceException
+	 */
+	public function requiresTranslation(
+		Account $account,
+		Mailbox $mailbox,
+		Message $message,
+		string $currentUserId,
+	): ?bool {
+		if (!in_array(FreePromptTaskType::class, $this->textProcessingManager->getAvailableTaskTypes(), true)) {
+			$this->logger->info('No language model available for checking translation needs');
+			return null;
+		}
+
+		$language = explode('_', $this->l->getLanguageCode())[0];
+		$cachedValue = $this->cache->getValue('needsTranslation_' . $language . $message->getId());
+		if ($cachedValue) {
+			return  $cachedValue === 'true' ? true : false;
+		}
+
+		$client = $this->clientFactory->getClient($account);
 		try {
-			$manager = $this->container->get(IManager::class);
-		} catch (\Throwable $e) {
+			$imapMessage = $this->mailManager->getImapMessage(
+				$client,
+				$account,
+				$mailbox,
+				$message->getUid(),
+				true,
+			);
+		} finally {
+			$client->logout();
+		}
+
+		if (!$this->isPersonalEmail($imapMessage)) {
 			return false;
 		}
-		return in_array($taskType, $manager->getAvailableTaskTypes(), true);
+
+		$messageBody = $imapMessage->getPlainBody();
+		$messageBody = str_replace('"', '\"', $messageBody);
+
+		$prompt = "Consider the following TypeScript function prototype:
+---
+/**
+ * This function takes in an email text and returns a boolean indicating whether the email needs translation from a specific language.
+ *
+ * @param emailText - string with the email text
+ * @param language - the language code to check against (e.g., 'en', 'de', etc.)
+ * @returns boolean true if the email is written in a different language than the one specified and needs translation, false if it is written in the specified language.
+ * only return true if whole sentences are written in a different language, not just a word or two.
+ */
+declare function isEmailWrittenInLanguage(emailText: string, language: string): Promise<boolean>;
+---
+Tell me what the function outputs for the following parameters.
+
+emailText: \"$messageBody\"
+language: \"$language\"
+The JSON output should be in the form: {\"needsTranslation\": true}
+Never return null or undefined.";
+		$task = new TextProcessingTask(FreePromptTaskType::class, $prompt, Application::APP_ID, $currentUserId);
+
+		$this->textProcessingManager->runTask($task);
+		$output = $task->getOutput();
+		if ($output === null) {
+			throw new ServiceException('Task output is null, possibly due to an error in the task processing', [
+				'messageId' => $message->getId(),
+				'language' => $language,
+				'output' => $output,
+			]);
+		}
+		// Can't use json_decode() here because the output contains additional garbage
+		$result = preg_match('/{\s*"needsTranslation"\s*:\s*true\s*}/i', $output) === 1;
+		$this->cache->addValue('needsTranslation_' . $language . $message->getId(), $result ? 'true' : 'false');
+		return $result;
+	}
+
+	public function isLlmAvailable(string $taskType): bool {
+		return in_array($taskType, $this->textProcessingManager->getAvailableTaskTypes(), true);
 	}
 
 	public function isTaskAvailable(string $taskName): bool {
